@@ -236,12 +236,13 @@ BLOCK
 CLEF
 BAR
 DBLQUOTE
+FERMATA
 
 
 ;;;;;;; Nils tokens for Denemo
 WHITESPACE { } ERROR VERSION
 
-SUP_QUOTE SUB_QUOTE PLUS EQUAL 
+SUP_QUOTE SUB_QUOTE PLUS EQUAL BRACKET_OPEN BRACKET_CLOSE TILDE
 
 DIGIT STAR 
 DOT 
@@ -546,15 +547,15 @@ HYPHEN
 ;; context_mod:
 ;; context_prop_spec:
  (context_prop_spec
-	(simple_string) : "FIXME"
-	(simple_string DOT simple_string) : "FIXME"
+	(simple_string) : $1
+	(simple_string DOT simple_string) : (string-append $1 "." $3) 
  )
 
  (simple_music_property_def
-	;(OVERRIDE context_prop_spec property_path EQUAL scalar) : (cons 'x_OVERRIDE "FIXME")
-	(REVERT context_prop_spec embedded_scm) :  (cons 'x_REVERT "FIXME")
-	(SET context_prop_spec EQUAL scalar) :  (cons 'x_SET "FIXME")
-	(UNSET context_prop_spec) :  (cons 'x_UNSET "FIXME")
+	;(OVERRIDE context_prop_spec property_path EQUAL scalar) : (lyimport::error "x_OVERRIDE"); (cons 'x_OVERRIDE (cons (cons $2 $3) $5))
+	(REVERT context_prop_spec embedded_scm) : (lyimport::error "x_REVERT"); (cons 'x_REVERT (cons $2 $3))
+	(SET context_prop_spec EQUAL scalar) :  (cons 'x_SET (cons $2 $4))
+	(UNSET context_prop_spec) :  (lyimport::error "x_UNSET"); (cons 'x_UNSET $2)
 )
 
 (music_property_def
@@ -645,17 +646,17 @@ HYPHEN
  (command_element
 	(command_event) : $1
 	(SKIP duration_length) : (string-append $1 $2)    ;	$$ = MAKE_SYNTAX ("skip-music", @$, $2);
-	(E_BRACKET_OPEN) : (lyimport::error "E_BRACKET_OPEN") ;	Music *m = MY_MAKE_MUSIC ("LigatureEvent", @$); m->set_property ("span-direction", scm_from_int (START)); 	$$ = m->unprotect();
-	(E_BRACKET_CLOSE) : (lyimport::error "E_BRACKET_CLOSE") ; Music *m = MY_MAKE_MUSIC ("LigatureEvent", @$); m->set_property ("span-direction", scm_from_int (STOP));	$$ = m->unprotect ();
+	(BRACKET_OPEN) : (cons 'x_BRACKET_OPEN $1) ;	Music *m = MY_MAKE_MUSIC ("LigatureEvent", @$); m->set_property ("span-direction", scm_from_int (START)); 	$$ = m->unprotect();
+	(BRACKET_CLOSE) : (cons 'x_BRACKET_CLOSE $1) ; Music *m = MY_MAKE_MUSIC ("LigatureEvent", @$); m->set_property ("span-direction", scm_from_int (STOP));	$$ = m->unprotect ();
 	(E_BACKSLASH) : (lyimport::error "E_BACKSLASH") ; $$ = MAKE_SYNTAX ("voice-separator", @$, SCM_UNDEFINED);
 	(PIPE)		: (cons 'x_BARLINE $1) ; look in parser.yy 
-	(PARTIAL duration_length): (lyimport::error "PARTIAL") ;		Moment m = - unsmob_duration ($2)->get_length (); 		$$ = MAKE_SYNTAX ("property-operation", @$, SCM_BOOL_F, ly_symbol2scm ("Timing"), ly_symbol2scm ("PropertySet"), ly_symbol2scm ("measurePosition"), m.smobbed_copy ()); 	$$ = MAKE_SYNTAX ("context-specification", @$, ly_symbol2scm ("Score"), SCM_BOOL_F, $$, SCM_EOL, SCM_BOOL_F);
+	(PARTIAL duration_length): (cons 'x_PARTIAL (cons (list-ref $2 0) (list-ref $2 1))) ; we get a list here: (duration numberofdots) Moment m = - unsmob_duration ($2)->get_length (); 		$$ = MAKE_SYNTAX ("property-operation", @$, SCM_BOOL_F, ly_symbol2scm ("Timing"), ly_symbol2scm ("PropertySet"), ly_symbol2scm ("measurePosition"), m.smobbed_copy ()); 	$$ = MAKE_SYNTAX ("context-specification", @$, ly_symbol2scm ("Score"), SCM_BOOL_F, $$, SCM_EOL, SCM_BOOL_F);
 	(TIME_T fraction) : (cons 'x_TIME $2) ; SCM proc = ly_lily_module_constant ("make-time-signature-set"); $$ = scm_apply_2   (proc, scm_car ($2), scm_cdr ($2), SCM_EOL);
 	(MARK scalar) : (lyimport::error "MARK scalar") ; SCM proc = ly_lily_module_constant ("make-mark-set"); 	$$ = scm_call_1 (proc, $2);
  )
 
 (command_event
-	(E_TILDE) : (lyimport::error "E_TILDE") ; $$ = MY_MAKE_MUSIC ("PesOrFlexaEvent", @$)->unprotect ();
+	(TILDE) : (cons 'x_TIE $1) ; $$ = MY_MAKE_MUSIC ("PesOrFlexaEvent", @$)->unprotect ();
 	(MARK DEFAULT) : (begin (cons 'x_LILYPOND "\\mark \\default")); 	  {
 						;Music *m = MY_MAKE_MUSIC ("MarkEvent", @$);
 						;$$ = m->unprotect ();
@@ -693,6 +694,7 @@ HYPHEN
   (MARKUP) : $1
   (script_dir direction_reqd_event) : $2;ignoring the up/down/center attribute (cons $1 $2)
   (string_number_event) : $1 
+  (FERMATA) : $1
  )
   
 
