@@ -65,18 +65,41 @@ typedef enum
 typedef enum DenemoGraphicType
   {
     DENEMO_BITMAP,
-    DENEMO_PATTERN
+    DENEMO_PATTERN,
+    DENEMO_FONT
   } DenemoGraphicType;
 
+typedef struct DenemoGlyph
+{
+  gchar *fontname;/**< font to be used */
+  gchar *utf; /**< utf8 char(s) to be placed as graphic */
+  gdouble size; /**< font size to be used */
+  gint slant, weight; /**< CAIRO_FONT_SLANT_xxx and WEIGHT_xxx values */
+}
+DenemoGlyph;
+
 typedef struct DenemoGraphic
 {
   DenemoGraphicType type;
-  gpointer graphic; /**< either a GdkBitmap or a cairo_pattern_t */
+  gpointer graphic; /**< either a GdkBitmap, a cairo_pattern_t or a DenemoGlyph*/
   gint width, height;
 }
 DenemoGraphic;
 
 
+typedef struct DenemoSelection
+{
+    gint firststaffmarked;
+    gint laststaffmarked;
+    gint firstmeasuremarked;
+    gint lastmeasuremarked;
+    gint firstobjmarked;
+    gint lastobjmarked;
+}
+DenemoSelection;
+
+
+
 /* The idea here is to make everything recursive.  The dominant
    paradigm is a linked list.  Handy that there's such a nice
    precooked implementation of them in glib, eh?  Note, however, that
@@ -190,7 +213,7 @@ typedef struct
 {
   DenemoObjType type; /**< The type of object pointed to by the gpointer object field below */
   gchar *user_string;/**< Holds user's original text parsed to generated this 
-			object */
+			object OBSOLETE */
   gint basic_durinticks; /**< Duration of object including dotting but not tuplet/grace note effects. */
   gint durinticks; /**< Duration of object where 384 (PPQN) is a quarter note, includes any tuplet/grace note effects */
   gint starttick; /**< When the object occurs */ 
@@ -207,6 +230,7 @@ typedef struct
   gboolean isend_beamgroup; /**< TRUE if this is the end of a beam group */
   gpointer object; /**< the structures pointed to are given in denemo_objects.h */
   gboolean isinvisible; /**< If  TRUE it will be drawn in a distinctive color and will be printed transparent. */
+  GList *directives; /* Directives attached to the object. These are transient */
 } DenemoObject;
 
 
@@ -241,7 +265,7 @@ typedef struct
 {
   GtkMenu *staffmenu; /**< a menu to popup up with the staff directives attached */
   GtkMenu *voicemenu; /**< a menu to popup up with the voice directives attached */
-
+  GList *sources;/**< List of source pixbufs, one for each measure staff-view */
   measurenode *measures; /**< This is a pointer to each measure in the staff */
   clef clef; /**< The initial clef see denemo_objects.h clefs */
   keysig keysig;
@@ -261,7 +285,7 @@ typedef struct
   gint no_of_lines; /**< Number of lines on the staff */
   gint transposition; /**< Determines if the notes are to be played back at pitch or not */
 
-  gint volume;	/**< Volume used for midi/csound playback */
+  gint volume;	/**< Volume used for midi playback */
   gboolean mute_volume; /**< mute Volume of voices playback */
   /* Back to Hiller stuff */
   //  GString *staff_name;
@@ -370,11 +394,12 @@ typedef struct DenemoPrefs
   GString *profile; /**< Which set of commands and shortcuts to load, and which initialization of scheme to run */
   GString *lilypath; /**< This is the executable or full path to the lilypond executable */
   GString *midiplayer; /**< This is the external midifile player */ 
-  GString *audioplayer; /**< This is used for playing audio files created from csound or other */
-  gboolean playbackoutput; /**< This is a switch to turn on playing the csound output 
-			     wav file after rendering or not */
+  GString *audioplayer; /**< This is used for playing audio files*/
+  GString *fontspec; /**< Font specification usually Denemo as this has the required characters */
   gboolean immediateplayback; /**< This options sends audio directly to synth as notes 
 				are being entered */
+  gint pitchspellingchannel; /**< channel to use for feedback when entering extreme intervals via MIDI in, that may indicate an enharmonic error, 0 means no pitch spelling*/
+  gint pitchspellingprogram; /**< program to set pitchspellingchannel to on startup */
   gboolean startmidiin; /**< try to start midi in on startup */
   gboolean applytoselection; /**< apply commands to selection */
   gboolean quickshortcuts;/**< TRUE if pressing a key while hovering over a menu item sets a shortcut */
@@ -401,6 +426,7 @@ typedef struct DenemoPrefs
 
   gboolean visible_directive_buttons; /**< This option makes the hbox containing score/movement directives visible */
 
+  gboolean enable_thumbnails;
   gboolean disable_undo; /**< Do not collect undo information */
   gboolean saveparts; /**< Automatically save parts*/
   gboolean autosave; /**< Auto save data */
@@ -410,9 +436,6 @@ typedef struct DenemoPrefs
   GString *browser; /**< Default browser string */
   
   const gchar *midi_audio_output; /**< How the user wants to deal with audio/midi output */
-  GString *csoundcommand; /**< command used to execute csound */
-  GString *csoundorcfile; /**< Path to .orc file used for csound playback */
-  gboolean rtcs; /**< Real time csound */
   GString *sequencer;  /**< path to sequencer device */
   GString *midi_in;  /**< path to midi_in device */
   gboolean jacktransport; /**< toggle on and off jack transport */
@@ -427,7 +450,7 @@ typedef struct DenemoPrefs
   gboolean fluidsynth_chorus; /**< Toggle if chorus is applied to fluidsynth */
   gint fluidsynth_sample_rate;/**< sample rate in Hz > */
   gint fluidsynth_period_size;/**< The size of the audio buffers (in frames).> */
-
+  gint dynamic_compression;/**< percent compression of dynamic range desired when listening to MIDI-in */
   gdouble display_refresh;/**< time in ms between refresh of display during playback */
   gint animation_steps;/** < number of steps to use animating the page turns during playback */
   GString *pdfviewer; /**< PDF viewer */
@@ -721,7 +744,7 @@ typedef struct DenemoScore
   gint widthtoworkwith;
   gint staffspace;
 
-
+  GList *sources; /**< List of source pixbufs, one for each measure score-view*/
   gdouble start_time; /**< time in seconds to start playing at */
   gdouble end_time; /**< time to end playing at */
   DenemoObject *playingnow; /**< the last object played via MIDI; it must not be dereferenced as it may no longer exist */
@@ -777,7 +800,7 @@ typedef struct DenemoScore
    * if the cursor advances to the next measure from the next "insert chord"
    * operation */
   gint curmeasure_stem_directive;
-
+  gint pending_enshift;/**< accidental to be used for next inserted note, cleared on note insert */
 
 
   /* Is there a figured bass present, is so this relates the bass
@@ -788,12 +811,7 @@ typedef struct DenemoScore
   gint markstaffnum;
   gint markmeasurenum;
   gint markcursor_x;
-  gint firststaffmarked;
-  gint laststaffmarked;
-  gint firstmeasuremarked;
-  gint lastmeasuremarked;
-  gint firstobjmarked;
-  gint lastobjmarked;
+  DenemoSelection selection;
 
 
   movementcontrol movementcontrol;/*< Directives for control of the whole movement */
@@ -885,6 +903,7 @@ typedef struct DenemoGUI
   GString *filename;/**< the filename to save to */
   GString *tabname;/**< the name of windows tab */
   GString *autosavename;/**< the filename to autosave to, full path */
+  DenemoSelection thumbnail; /**< the selection from which to create a thumbnail on exit */
 
   gint undo_level;/**< level of script nesting 0 = staging point for undo to return to */
   gboolean notsaved;/**< edited since last save */
@@ -938,7 +957,6 @@ struct cs_callback
 	
 };
 
-//static gchar* ext_pidfiles[] = {"midiplayer.pid", "csoundplayer.pid", NULL};
 
 /** 
  * The (singleton) root object for the program
@@ -946,7 +964,9 @@ struct cs_callback
  */
 struct DenemoRoot
 {
-  gchar *schemeinit;/* filename for scheme code to run on startup */
+  gboolean non_interactive; /* if TRUE denemo should not display gui, receive or send sounds etc*/
+  gchar *scheme_file;/* filename for scheme code to run on startup */
+  gchar *scheme_commands;/* scheme code to run on startup after scheme_file */
   /* Fields used fairly directly for drawing */
   GtkWidget *page;
   GtkWidget *scorearea;
