@@ -10,9 +10,9 @@
 #include "twoints.h"
 
 struct twoints
-find_xes_in_measure (struct scoreinfo *si, gint measurenum,
+find_xes_in_measure (DenemoScore *si, gint measurenum,
 		     gint time1, gint time2);
 
-void find_xes_in_all_measures (struct scoreinfo *si);
+void find_xes_in_all_measures (DenemoScore *si);
 
-void set_rightmeasurenum (struct scoreinfo *si);
+void set_rightmeasurenum (DenemoScore *si);
