@@ -245,6 +245,7 @@ void modify_note(chord *thechord, gint mid_c_offset, gint enshift, gint dclef) {
      {DenemoStaff *curstaffstruct = (DenemoStaff *)  Denemo.gui->si->currentstaff->data;
     playnotes (Denemo.prefs.immediateplayback, thechord, curstaffstruct->midi_channel);
   }
+  displayhelper(Denemo.gui);
 }
 
 /* Allocate a new note structure initializing the fields
@@ -253,6 +254,8 @@ void modify_note(chord *thechord, gint mid_c_offset, gint enshift, gint dclef) {
 
 static note *new_note(gint mid_c_offset, gint enshift, gint dclef) {
   note *newnote;
+  if(enshift>2) enshift = 2;
+  if(enshift<-2) enshift = -2;
   newnote = (note *) g_malloc0 (sizeof (note));
   newnote->mid_c_offset = mid_c_offset;
   newnote->enshift = enshift;
@@ -270,7 +273,8 @@ static note *new_note(gint mid_c_offset, gint enshift, gint dclef) {
 note *
 addtone (DenemoObject * thechord, gint mid_c_offset, gint enshift, gint dclef)
 {
-  note *newnote  = new_note(mid_c_offset, enshift, dclef);
+  note *newnote  = new_note(mid_c_offset, Denemo.gui->si->pending_enshift+enshift, dclef);
+  Denemo.gui->si->pending_enshift = 0;
   ((chord *) thechord->object)->notes =
     g_list_insert_sorted (((chord *) thechord->object)->notes, newnote,
 			  insertcomparefunc);
@@ -424,6 +428,7 @@ changeenshift (DenemoObject * thechord, gint mid_c_offset, gint accidental)
     {
       tone = (note *) tnode->data;
       tone->enshift = accidental;
+      displayhelper(Denemo.gui);
     }
 }
 
@@ -523,6 +528,7 @@ freechord (DenemoObject * thechord)
     free_directives(((chord *) thechord->object)->directives);
     //g_list_free(((chord *) thechord->object)->directives);
   }
+//FIXME we should free thechord->directives too if scripts fail to delete them
   g_free (thechord);
 }
 
@@ -545,8 +551,8 @@ clone_chord (DenemoObject * thechord)
   memcpy ((DenemoObject *) ret, (DenemoObject *) thechord,
 	  sizeof (DenemoObject));
 
-  ret->object = NULL;//currently the only pointer in DenemoObject
-
+  ret->object = NULL;
+  ret->directives = NULL;//currently the only pointers in DenemoObject
   memcpy ((chord *) clonedchord, curchord, sizeof (chord));
   clonedchord->directives = NULL;
   clonedchord->dynamics = NULL;
