@@ -34,7 +34,7 @@
 
 static gboolean
 draw_score (cairo_t *cr);
-GdkPixbuf *StaffPixbuf, *StaffPixbufSmall;
+GdkPixbuf *StaffPixbuf, *StaffPixbufSmall, *StaffGoBack, *StaffGoForward;
 #define MAX_PLAYHEADS (100)
 static GdkRectangle old_playhead_damage[MAX_PLAYHEADS];
 static GdkRectangle new_playhead_damage[MAX_PLAYHEADS];
@@ -103,6 +103,8 @@ create_tool_pixbuf(void) {
   GtkWidget *widget = gtk_button_new();
   StaffPixbuf = gtk_widget_render_icon (widget, GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_BUTTON, "denemo");
   StaffPixbufSmall = gtk_widget_render_icon (widget, GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU, "denemo");
+  StaffGoBack = gtk_widget_render_icon (widget, GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON, "denemo");
+  StaffGoForward = gtk_widget_render_icon (widget, GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON, "denemo");
 }
 
 
@@ -150,12 +152,14 @@ struct infotopass
   gint objnum;
   gint measurenum;//would need measurenum_adj to allow control of numbering after pickup etc...
   gint staffnum;
+  gboolean end;//if we have drawn the last measure
   gint top_y;
   gint last_gap;//horizontal gap from last object
   gint markx1, markx2;
   gint marky1, marky2;
   gboolean line_end;//set true when an object is drawn off the right hand edge
-
+  gint tupletstart;//x-coordinate where tuplet started, 0 if none
+  gint tuplety;//y-coordinate of highest note within tuplet
   measurenode *curmeasure;
   GList *mwidthiterator;
   GSList *slur_stack;
@@ -167,6 +171,7 @@ struct infotopass
   gint lowy;/*(return) the lowest y value drawn*/
   gint in_highy; // FIXME these are passed in so that highy, lowy do not need to be passed back
   gint in_lowy;
+  gboolean source_displayed;//if pixbufs (sources) have been displayed for a staff - show no further staff content
   gboolean mark;//whether the region is selected
   gint *left, *right;//pointer into array, pointing to leftmost/rightmost measurenum for current system(line)
   gint *scale;//pointer into an array of scales - this entry is the percent horizontal scale applied to the current system
@@ -225,31 +230,15 @@ static gint
 draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 	     DenemoGUI * gui, struct infotopass *itp)
 {
-  //g_print("draw obj %p\n", cr);
 
-  static gboolean init=FALSE;
-  static GdkColor white, black, blue, green, yellow;
-  if(!init) {
-    gdk_color_parse ("white", &white);
-    gdk_colormap_alloc_color (gdk_colormap_get_system (), &white, TRUE, TRUE);
-    gdk_color_parse ("black", &black);
-    gdk_colormap_alloc_color (gdk_colormap_get_system (), &black, TRUE, TRUE);
-    gdk_color_parse ("blue", &blue);
-    gdk_colormap_alloc_color (gdk_colormap_get_system (), &blue, TRUE, TRUE);
-    gdk_color_parse ("green", &green);
-    gdk_colormap_alloc_color (gdk_colormap_get_system (), &green, TRUE, TRUE);
-    gdk_color_parse ("yellow", &yellow);
-    gdk_colormap_alloc_color (gdk_colormap_get_system (), &yellow, TRUE, TRUE);
-    init = TRUE;
-  }
+
   itp->highy = itp->lowy = 0;
   DenemoScore *si = gui->si;
   DenemoObject *mudelaitem = (DenemoObject *) curobj->data;
 
-
+  //g_print("draw obj %d %d\n", mudelaitem->x, y);
   //this is the selection being given a blue background
-  //FIXME NO! save and restore are *fast*. too much save and restore for trifling reasons...
-  if(cr) if(/* Denemo.gui->si->playingnow==NULL && show selection during playback*/ itp->mark) {
+  if(cr) if(itp->mark) {
     cairo_save(cr);
     cairo_set_source_rgb( cr, 0.5, 0.5, 1.0 );
     cairo_rectangle (cr, x+mudelaitem->x, y, 20, 80 );
@@ -270,10 +259,6 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
        add_playhead_damage((x+mudelaitem->x)*Denemo.gui->si->zoom*100.0/(*itp->scale), y*Denemo.gui->si->zoom, 20*Denemo.gui->si->zoom*100.0/(*itp->scale), 80*Denemo.gui->si->zoom);   
      }
    }
-   
-
-
-
 
   /* The current note, rest, etc. being painted */
  
@@ -282,18 +267,10 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 
   if(mudelaitem == itp->startobj)
     itp->startposition = x + mudelaitem->x + mudelaitem->minpixelsalloted; 
-#if 0
- if(itp->startobj==NULL && itp->startposition<=0)
-   itp->startposition = x;
-#endif
+
   if(mudelaitem == itp->endobj)
     itp->endposition = x + mudelaitem->x + mudelaitem->minpixelsalloted;
 
-  //g_print("item %p draw at %d\n", mudelaitem, itp->playposition);
-  // if (!greengc)
-  //   greengc = gcs_greengc ();
-  /* Should we set cursor-context info before drawing? */
-
   /************ FIXME the drawing is side-effecting the DenemoScore si here *******************/
   if (si->currentobject == curobj)
     {
@@ -315,14 +292,17 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
     case CHORD:
       { chord *thechord = ((chord *) mudelaitem->object);
 
-	if(cr) draw_chord ( cr, curobj, x + mudelaitem->x, y,
+	draw_chord ( cr, curobj, x + mudelaitem->x, y,
 		     GPOINTER_TO_INT (itp->mwidthiterator->data),
 		     itp->curaccs, itp->mark);
 	if((thechord->highesty) < itp->highy)
 	  itp->highy  = thechord->highesty/*, g_print("setting highy %d\n", itp->highy)*/;
+	  
 	
 	if((thechord->lowesty) > itp->lowy+STAFF_HEIGHT)
 	  itp->lowy  = thechord->lowesty-STAFF_HEIGHT;
+
+	if(itp->tupletstart) itp->tuplety = MAX(0, MAX(itp->tuplety, MAX(-thechord->lowesty, -thechord->highesty)));
 	
 	if (thechord->is_fakechord)
 	  	if(cr) draw_fakechord (cr,
@@ -408,9 +388,14 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
       }
       break;
     case TUPOPEN:
+      itp->tupletstart = x + mudelaitem->x;
+      if(cr) draw_tupbracket (cr,
+		       x + mudelaitem->x, y, mudelaitem, 0);
+      break;
     case TUPCLOSE:
       if(cr) draw_tupbracket (cr,
-		       x + mudelaitem->x, y, mudelaitem);
+		       x + mudelaitem->x, y - itp->tuplety, mudelaitem, itp->tupletstart);
+      itp->tupletstart = itp->tuplety = 0;
       break;
     case LILYDIRECTIVE:
       // if(si->markstaffnum) not available
@@ -451,6 +436,7 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
 	}
       /* The following assumes no multiple simultaneous time signatures */
       itp->tickspermeasure = WHOLE_NUMTICKS * itp->time1 / itp->time2;
+      itp->wholenotewidth = si->measurewidth * itp->time2 / itp->time1;
       break;
     case STEMDIRECTIVE:
       if(cr) draw_stem_directive (cr,
@@ -496,14 +482,14 @@ draw_object (cairo_t *cr, objnode * curobj, gint x, gint y,
   itp->last_gap = extra;
   /* Now quite possibly update the mark */
 
-  if (si->firststaffmarked == itp->staffnum
-      && si->firstmeasuremarked == itp->measurenum
-      && si->firstobjmarked == itp->objnum)
+  if (si->selection.firststaffmarked == itp->staffnum
+      && si->selection.firstmeasuremarked == itp->measurenum
+      && si->selection.firstobjmarked == itp->objnum)
     itp->markx1 = x + mudelaitem->x - EXTRAFORSELECTRECT;
 
-  if (si->laststaffmarked == itp->staffnum
-      && si->lastmeasuremarked == itp->measurenum
-      && si->lastobjmarked == itp->objnum)
+  if (si->selection.laststaffmarked == itp->staffnum
+      && si->selection.lastmeasuremarked == itp->measurenum
+      && si->selection.lastobjmarked == itp->objnum)
     itp->markx2 = x + mudelaitem->x + mudelaitem->minpixelsalloted
       + EXTRAFORSELECTRECT;
 
@@ -534,6 +520,7 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
 	      DenemoGUI * gui, struct infotopass *itp)
 {
   static GString *mstring;
+  gint last_type = -1;//type of last object in measure
   gint extra_ticks = 0;//number of ticks by which measure is over-full
   DenemoScore *si = gui->si;
   objnode *curobj;
@@ -578,19 +565,19 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
   curobj = (objnode *) curmeasure->data;
   /* These default values for the markx'es may be necessary down
    * the road */
-  if (si->firststaffmarked == itp->staffnum
-      && si->firstmeasuremarked == itp->measurenum)
+  if (si->selection.firststaffmarked == itp->staffnum
+      && si->selection.firstmeasuremarked == itp->measurenum)
     {
       if (!curobj)
 	itp->markx1 = x - EXTRAFORSELECTRECT;
       else
 	itp->markx1 = x + GPOINTER_TO_INT (itp->mwidthiterator->data);
     }
-  if (si->laststaffmarked == itp->staffnum
-      && si->lastmeasuremarked == itp->measurenum)
+  if (si->selection.laststaffmarked == itp->staffnum
+      && si->selection.lastmeasuremarked == itp->measurenum)
     {
       if (!curobj
-	  || (si->lastobjmarked >=
+	  || (si->selection.lastobjmarked >=
 	      (gint) (g_list_length ((objnode *) curobj))))
 	itp->markx2 =
 	  x + GPOINTER_TO_INT (itp->mwidthiterator->data) +
@@ -602,26 +589,26 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
 
 
   gboolean not_marked = (!si->markstaffnum) ||
-    (si->firststaffmarked >itp->staffnum) || 
-    (si->laststaffmarked < itp->staffnum) ||
-    (si->firstmeasuremarked > itp->measurenum) ||
-    (si->lastmeasuremarked < itp->measurenum);
+    (si->selection.firststaffmarked >itp->staffnum) || 
+    (si->selection.laststaffmarked < itp->staffnum) ||
+    (si->selection.firstmeasuremarked > itp->measurenum) ||
+    (si->selection.lastmeasuremarked < itp->measurenum);
 
   gboolean definitely_marked = (!not_marked) &&
-    (si->firstmeasuremarked < itp->measurenum) &&
-    (si->lastmeasuremarked > itp->measurenum);
-  gboolean in_firstmeas = (si->firstmeasuremarked == itp->measurenum);
-  gboolean in_lastmeas = (si->lastmeasuremarked == itp->measurenum);
+    (si->selection.firstmeasuremarked < itp->measurenum) &&
+    (si->selection.lastmeasuremarked > itp->measurenum);
+  gboolean in_firstmeas = (si->selection.firstmeasuremarked == itp->measurenum);
+  gboolean in_lastmeas = (si->selection.lastmeasuremarked == itp->measurenum);
   /* Draw each mudelaitem */
   for (itp->objnum = 0; curobj; curobj = curobj->next, itp->objnum++) {
     itp->mark =  (definitely_marked) || 
       ((!not_marked) && ((in_firstmeas && !in_lastmeas &&
-			 (si->firstobjmarked <= itp->objnum)) ||
+			 (si->selection.firstobjmarked <= itp->objnum)) ||
 		       (in_lastmeas && !in_firstmeas &&
-		        (si->lastobjmarked >= itp->objnum)) ||
+		        (si->selection.lastobjmarked >= itp->objnum)) ||
 			 (in_lastmeas && in_firstmeas && 
-			  (si->firstobjmarked <= itp->objnum) && 
-			  (si->lastobjmarked >= itp->objnum)))
+			  (si->selection.firstobjmarked <= itp->objnum) && 
+			  (si->selection.lastobjmarked >= itp->objnum)))
        );
 
 
@@ -637,8 +624,7 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
     extra_ticks = draw_object (cr, curobj, x, y, gui, itp);
 
     {DenemoObject *obj = (DenemoObject *) curobj->data;
-      if(Denemo.gui->si->smf)
-	;//g_print("Latest %f earliest %f Obj type %d\n", obj->latest_time, obj->earliest_time, obj->type);
+     last_type = obj->type;
     }
     //itp->rightmosttime = curobj->latest_time;//we just want this for the rightmost object 
   } // for each object
@@ -647,41 +633,53 @@ draw_measure (cairo_t *cr, measurenode * curmeasure, gint x, gint y,
     //marking the barline if within selection
     if(si->markstaffnum && 
 /*        (curmeasure->data==NULL) && */
-       (si->firststaffmarked <= itp->staffnum) &&
-       (si->laststaffmarked >= itp->staffnum) &&
-       (si->firstmeasuremarked <= itp->measurenum) &&
-       (si->lastmeasuremarked > itp->measurenum))
-      {
-	cairo_set_source_rgb( cr, 0.5, 0.5, 1.0 );
-	cairo_rectangle (cr, x + GPOINTER_TO_INT (itp->mwidthiterator->data), y, 20, STAFF_HEIGHT+1); 
-	cairo_fill(cr);
-      }
-    
-    /* Paint the exclamation point, if necessary */
-    
-    if( extra_ticks > 0 )
-      cairo_set_source_rgb( cr, 1.0, 0, 0 );
-    else
-      cairo_set_source_rgb( cr, 0, 0, 1 );
-    if(extra_ticks != 0) {
-      drawlargetext_cr( cr, "!", x, y - 8 );
-      //cairo_set_source_rgb( cr, 0.5, 0.5, 0.5 );
-    } else
-      cairo_set_source_rgb( cr, 0, 0, 0 );
-    //draw the barline
+       (si->selection.firststaffmarked <= itp->staffnum) &&
+       (si->selection.laststaffmarked >= itp->staffnum) &&
+       (si->selection.firstmeasuremarked <= itp->measurenum) &&
+       (si->selection.lastmeasuremarked > itp->measurenum))      {
+	  cairo_set_source_rgb( cr, 0.5, 0.5, 1.0 );
+	  cairo_rectangle (cr, x + GPOINTER_TO_INT (itp->mwidthiterator->data), y, 20, STAFF_HEIGHT+1); 
+	  
+	  cairo_fill(cr);
+    } 
+      /* Indicate fill status  */
+#define OPACITY (0.3)
+    if(curmeasure->data) {
+	if(extra_ticks > 0 )
+	  cairo_set_source_rgba( cr, 1.0, 0.8, 0.8, OPACITY);
+	else if((extra_ticks < 0) && curmeasure->next )
+	  cairo_set_source_rgba( cr, 0.8, 0.8, 1, OPACITY);
+#undef OPACITY     
+	if((extra_ticks > 0 ) || ((extra_ticks < 0 ) && (curmeasure->next) && curmeasure->next->data)) {
+	  cairo_rectangle (cr, x , y, GPOINTER_TO_INT (itp->mwidthiterator->data), STAFF_HEIGHT+1);        
+	  cairo_fill(cr);
+	  extra_ticks>0 ? cairo_set_source_rgb( cr, 1, 0, 0 ):cairo_set_source_rgb( cr, 0, 0, 1 );
+	} else {
+	cairo_set_source_rgb( cr, 0, 0, 0 );
+       }
+    }
+    if(extra_ticks == 0)  {
+	cairo_set_source_rgb( cr, 0, 0, 0 );
+    }
 
+    //draw the barline
     cairo_rectangle (cr, x + GPOINTER_TO_INT (itp->mwidthiterator->data), y-0.5, 1.5, STAFF_HEIGHT+1);
     cairo_fill(cr);
 
-
-    if (!curmeasure->next)
+    if ((!curmeasure->next))
       {
-	/* we've reached the end of the score and should
-	 * draw the heavy part of double-barline at regular position */
+	/* we've reached the end of the staff and should
+	 * draw the heavy part of double-barline unless there is a directive here in which case it takes responsibility for the type of barline */
 	x += 3;
-	cairo_rectangle (cr, x + GPOINTER_TO_INT (itp->mwidthiterator->data), y-0.5, 4, STAFF_HEIGHT+1);
-	cairo_fill(cr);
+	if(last_type != LILYDIRECTIVE) {
+	  cairo_rectangle (cr, x + GPOINTER_TO_INT (itp->mwidthiterator->data), y-0.5, 4, STAFF_HEIGHT+1);
+	  cairo_fill(cr);
+	}
+	itp->end = TRUE;
       }	
+    else {
+      itp->end = FALSE;
+    }
     cairo_restore(cr);
   } //if cr
 
@@ -751,17 +749,28 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
       thestaff->leftmost_timesig->time1;
     itp->time2 =
       thestaff->leftmost_timesig->time2;
-    if(cr) draw_timesig (cr, x, y, itp->time1, itp->time2);
+    if(cr) {
+      if(si->leftmeasurenum==1)  
+	draw_timesig (cr, x, y, itp->time1, itp->time2);
+      else {
+	guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffGoBack));
+	guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffGoBack));
+	cairo_save( cr );
+	gdk_cairo_set_source_pixbuf( cr, GDK_PIXBUF(StaffGoBack), x,y );
+	cairo_rectangle( cr,x,y, width, height );
+	cairo_fill( cr );
+	cairo_restore( cr );
+      }
+    }
     x += SPACE_FOR_TIME;
-
   } else {
     if(cr) draw_clef (cr, LEFT_MARGIN, y, itp->clef);
     if(cr) draw_key (cr, x, y,
-	      itp->key, 0, itp->clef->type, TRUE);
+		     itp->key, 0, itp->clef->type, TRUE);
     x += si->maxkeywidth;
     x += SPACE_FOR_TIME;// to allow the same margin ??
   }
-
+  
   *itp->left = itp->measurenum>gui->si->rightmeasurenum?gui->si->rightmeasurenum:itp->measurenum; 
   memcpy (itp->keyaccs, thestaff->leftmost_keysig->accs, SEVENGINTS);
 
@@ -826,38 +835,57 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 
  gint scale_before=*itp->scale;
   itp->line_end = FALSE;
-  
+  cairo_t *saved_cr = NULL;
+  if(itp->source_displayed) {//We have displayed source material below the last staff, so do not draw anymore staff music. We cannot simply skip the drawing routines however, because they determine the rightmost bar for mouse positioning, so we save and restore it.
+    saved_cr = cr;
+    cr = NULL;
+  }
+    
   while ( (!itp->line_end) 
 	 && itp->measurenum <= nummeasures)
     {
       if( x + GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE >
 	  (int) (Denemo.scorearea->allocation.width/gui->si->zoom - (RIGHT_MARGIN + KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME)))
 	  itp->line_end=TRUE;
-	 
-      itp->last_gap = 0;
-      draw_measure (cr, itp->curmeasure, x, y, gui, itp);
 
-      x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
+	  itp->last_gap = 0;
+	  draw_measure (cr, itp->curmeasure, x, y, gui, itp);
+	  if(cr && (Denemo.gui->view!=DENEMO_PAGE_VIEW) && (si->sources||thestaff->sources) && (si->currentstaffnum == itp->staffnum)) {
+	    GdkPixbuf* source = (GdkPixbuf*)g_list_nth_data(si->sources?gui->si->sources:thestaff->sources, itp->measurenum-1);
+	    if(source) {	      
+		      gdouble width = (gdouble)gdk_pixbuf_get_width( GDK_PIXBUF(source));
+		      gdouble height = (gdouble)gdk_pixbuf_get_height( GDK_PIXBUF(source));
+		      gdouble scale = GPOINTER_TO_INT (itp->mwidthiterator->data)/width;
+		      gint ypos = y + 2*STAFF_HEIGHT+thestaff->space_below;
+		      gint xpos = x;
+		      cairo_save( cr );
+		      if(scale<1.0) {//too large to fit under the measure
+			cairo_translate( cr, x*(1-scale), ypos*(1-scale));
+			cairo_scale(cr, scale, scale);
+		      } else
+		      xpos = x - (width - GPOINTER_TO_INT (itp->mwidthiterator->data))/2;//narrow, center it
+		      gdk_cairo_set_source_pixbuf( cr, GDK_PIXBUF(source), xpos,ypos );
+		      cairo_rectangle( cr,xpos,ypos, width, height );
+		      cairo_fill( cr );
+		      cairo_restore( cr );
+		      itp->source_displayed = TRUE;
+	    }
+	  }
+	x += GPOINTER_TO_INT (itp->mwidthiterator->data) + SPACE_FOR_BARLINE;
 
-#if 0
-      if(itp->line_end) {
-      *itp->scale = itp->curmeasure->next?
-	(int)(100*x/(Denemo.scorearea->allocation.width/gui->si->zoom)):100;
-      }
-#else
-      if(itp->line_end && itp->curmeasure->next)
-	*itp->scale = (int)(100*x/(Denemo.scorearea->allocation.width/gui->si->zoom));
-      if( (Denemo.gui->view!=DENEMO_PAGE_VIEW) && *itp->scale < 100)
-	*itp->scale = 100;
-#endif
+	if((Denemo.gui->view!=DENEMO_PAGE_VIEW && itp->line_end && itp->measurenum > si->rightmeasurenum)
+	  ||(Denemo.gui->view==DENEMO_PAGE_VIEW && itp->line_end && itp->curmeasure->next))
+		*itp->scale = (int)(100*x/(Denemo.scorearea->allocation.width/gui->si->zoom));	
+	else
+	  *itp->scale = 100;
 
-      itp->curmeasure = itp->curmeasure->next;
-      itp->mwidthiterator = itp->mwidthiterator->next;
+    itp->curmeasure = itp->curmeasure->next;
+    itp->mwidthiterator = itp->mwidthiterator->next;
 
-      itp->measurenum++;
-      //g_print("line_end is %d, while itp->measurenum=%d and si->rightmeasurenum=%d\n",  itp->line_end, itp->measurenum, si->rightmeasurenum);
-      if(!itp->line_end) {
-	if(-itp->highy>itp->in_highy && -itp->highy<MAXEXTRASPACE){
+    itp->measurenum++;
+    //g_print("line_end is %d, while itp->measurenum=%d and si->rightmeasurenum=%d\n",  itp->line_end, itp->measurenum, si->rightmeasurenum);
+    if(!itp->line_end) {
+	if(-itp->highy>itp->in_highy && -itp->highy<MAXEXTRASPACE) {
 	  thestaff->space_above = -itp->highy;
 	  repeat = TRUE;
 	}
@@ -878,15 +906,28 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
 	  cairo_rectangle (cr, x - SPACE_FOR_BARLINE, y - STAFF_HEIGHT - prev->space_below - thestaff->space_above, 2, 2*STAFF_HEIGHT + prev->space_below + thestaff->space_above);
 	  cairo_fill(cr);	 
 	}
-      if(cr) if(curstaff->next)
-	{
-	  DenemoStaff *next = (DenemoStaff *)(curstaff->next->data);
-	  //cairo_save(cr);
-	  cairo_set_source_rgb( cr, 0, 0, 0);
-	  cairo_rectangle (cr, x - SPACE_FOR_BARLINE, y, 2, 2*STAFF_HEIGHT + next->space_above + thestaff->space_below);
-	  cairo_fill(cr);	 
-	}
+  if(cr) if(curstaff->next)
+	   {
+	     DenemoStaff *next = (DenemoStaff *)(curstaff->next->data);
+	     //cairo_save(cr);
+	     cairo_set_source_rgb( cr, 0, 0, 0);
+	     cairo_rectangle (cr, x - SPACE_FOR_BARLINE, y, 2, 2*STAFF_HEIGHT + next->space_above + thestaff->space_below);
+	     cairo_fill(cr);	 
+	   }
   /* end of draw lines connecting the staves in this system at the left and right hand ends */
+  if(cr)if(itp->line_end)if(itp->measurenum>si->rightmeasurenum)if(!itp->end)
+	   {
+	     guint width = gdk_pixbuf_get_width( GDK_PIXBUF(StaffGoForward));
+	     guint height = gdk_pixbuf_get_height( GDK_PIXBUF(StaffGoForward));
+	     cairo_save( cr );
+	     gint xx = Denemo.scorearea->allocation.width/gui->si->zoom -width;
+	     gdk_cairo_set_source_pixbuf( cr, GDK_PIXBUF(StaffGoForward),xx,y );
+	     cairo_rectangle( cr,xx,y, width, height );
+	     cairo_fill( cr );
+	     cairo_restore( cr );
+	   }
+
+
 
   if(cr) cairo_restore(cr);
   // if(itp->highy > title_highy)
@@ -911,7 +952,9 @@ draw_staff (cairo_t *cr, staffnode * curstaff, gint y,
       g_slist_free (itp->slur_stack);
       itp->slur_stack = NULL;
     }
-  //if(cr) cairo_restore(cr);
+  if(saved_cr)
+    cr = saved_cr;
+  
   return repeat;
 }
 static void
@@ -1000,7 +1043,7 @@ draw_score (cairo_t *cr)
   //g_print("Printing for %d\n", flip_count);
   itp.slur_stack = NULL;
   itp.hairpin_stack = NULL;
-
+  itp.source_displayed = FALSE;
   itp.highy = 0;//in case there are no objects...
   itp.lowy = 0;
   itp.last_gap = 0;
@@ -1009,6 +1052,7 @@ draw_score (cairo_t *cr)
   itp.startposition = -1;
   itp.endposition = -1;
   itp.startobj =  itp.endobj = NULL;
+  itp.tupletstart = itp.tuplety = 0;
   y = 0;
 
   if(gui->si->smf) {
@@ -1258,20 +1302,16 @@ DenemoGUI *gui = Denemo.gui;
  }
 
   /* Layout the score. */
- //if(!Denemo.gui->si->playingnow)
  if(layout_needed)
-   draw_score (NULL);
+   if(draw_score (NULL)) {
+      set_bottom_staff(gui);
+      update_vscrollbar(gui);
+   }
  layout_needed = TRUE;
- // while(draw_score (NULL, gui) && !Denemo.gui->si->playingnow)
- //   {/*nothing*/}
 
   /* Setup a cairo context for rendering and clip to the exposed region. */
   cr = gdk_cairo_create (event->window);
-
- 
   gdk_cairo_region (cr, event->region);
-  
-  //region_playhead(cr); //!!!!!!! but not both!!!!!!
   cairo_clip (cr);
 
   /* Clear with an appropriate background color. */
@@ -1281,12 +1321,10 @@ DenemoGUI *gui = Denemo.gui;
     GdkColor col;
     gdk_color_parse ("lightblue", &col);
     gdk_cairo_set_source_color (cr, &col);
-  } else if (GTK_WIDGET_IS_SENSITIVE (Denemo.scorearea)) {
-    //cairo_set_source_rgb (cr, 1,1,1);
+  } else if (gtk_widget_has_focus (Denemo.scorearea)) {
     cairo_set_source_rgb (cr, ((0xFF0000&Denemo.color)>>16)/255.0, ((0xFF00&Denemo.color)>>8)/255.0, ((0xFF&Denemo.color))/255.0);
   } else {
-    gdk_cairo_set_source_color (cr, widget->style->bg);
-   
+   cairo_set_source_rgb (cr, 0.9, 0.9, 0.9);
   }
   cairo_paint (cr);
 
