@@ -49,8 +49,8 @@ draw_clef (cairo_t *cr, gint xx, gint y, clef *clef)
 	drawnormaltext_cr( cr, directive->display->str, xx + directive->tx, y+count*10 );
       }
       if(directive->graphic) {
-	gint width, height;
-	gdk_drawable_get_size(GDK_DRAWABLE(directive->graphic), &width, &height);
+	//	gint width, height;
+	//gdk_drawable_get_size(GDK_DRAWABLE(directive->graphic), &width, &height);
 	drawbitmapinverse_cr (cr, directive->graphic,
 			   xx+directive->gx+count,  y+directive->gy);
       }
