@@ -20,43 +20,28 @@ draw_lily_dir (cairo_t *cr,
 {
   lilydirective *lily = ((lilydirective *) theobj->object);
   gchar *first = (lily->postfix && lily->postfix->len)? lily->postfix->str:" ";
-
+  cairo_save(cr);
+  selected?
+      cairo_set_source_rgb( cr, 0.0, 0.0, 1.0 ):
+      lily->graphic? cairo_set_source_rgb( cr, 0.0, 0.0, 0.0 ):
+          cairo_set_source_rgb( cr, 0.4, 0.5, 0.4 );
   if(lily->graphic){
     gint width = lily->graphic->width;
     gint  height = lily->graphic->height;  
-#if 0
-    drawbitmapinverse_cr (cr, (DenemoGraphic *)lily->graphic,
-		     xx + lily->gx, y + lily->gy);
-#else
-    //it seems this is what we should be doing - it means altering all the scripts...
+    //FIXME there may be scripts expecting a different positioning code
     drawbitmapinverse_cr (cr, (DenemoGraphic *)lily->graphic,
 			  xx + lily->gx - (((DenemoGraphic *)lily->graphic)->width)/2, y + MID_STAFF_HEIGHT + lily->gy -  (((DenemoGraphic *)lily->graphic)->height)/2);
-#endif
-
-
-  }
-  else
-  {
-    cairo_save(cr);
-    if(selected)
-      cairo_set_source_rgb( cr, 0.0, 0.0, 1.0 );
-    else
-      cairo_set_source_rgb( cr, 0.4, 0.5, 0.4 );
-
+  } else {
     cairo_rectangle (cr, xx/*-2*/, y, 10, STAFF_HEIGHT);
     cairo_fill( cr );
-    cairo_restore(cr);
   }
   if(lily->display) {  //store display position x,y as well
     drawnormaltext_cr( cr, lily->display->str, xx+ lily->tx, y+lowy+lily->ty );
   }
-#if 1
   else
-  //do this by creating a display field
-
-  if( *first == '%' || *first == '^' || *first == '_' ) { //display comments, and markup above and below
-    drawnormaltext_cr( cr, first+1, xx, *first=='_'?y+lowy+20:y-highy-20 );
-  }
-#endif
-
+  //FIXME do this by creating a display field
+    if( *first == '%' || *first == '^' || *first == '_' ) { //display comments, and markup above and below
+      drawnormaltext_cr( cr, first+1, xx, *first=='_'?y+lowy+20:y-highy-20 );
+    }
+    cairo_restore(cr);
 }
