@@ -11,7 +11,7 @@
 
 #include <denemo/denemo.h>
 
-void exportabc (gchar * thefilename, DenemoScore *si, gint start,
+void exportabc (gchar * thefilename, DenemoGUI *gui, gint start,
 		gint end);
 
 
