@@ -112,12 +112,12 @@ separate_fakechord_elements (gchar *fakechord, DenemoObject *curObj)
   if (curObj && curObj->type == CHORD) {
     ((chord *) curObj->object)->is_fakechord = TRUE;
     ((chord *) curObj->object)->fakechord = base;
-    if (has_extension)
-      ((chord *) curObj->object)->fakechord_extension = extension;
-    else {
+    //if (has_extension)
+    //((chord *) curObj->object)->fakechord_extension = extension;
+    //else {
       g_string_free(extension, TRUE);
-      ((chord *) curObj->object)->fakechord_extension = NULL;
-    }
+      //((chord *) curObj->object)->fakechord_extension = NULL;
+      //}
   }
   
 }
@@ -138,16 +138,19 @@ insertfakechord (GtkWidget * widget, gpointer data)
   if(cbdata->string==NULL)
     return FALSE;
   if (si->currentobject != NULL) {
-	  DenemoObject *curObj = (DenemoObject *) si->currentobject ?
-	    (DenemoObject *) si->currentobject->data : NULL;
-	  gchar *fakechord = cbdata->string;
-	  separate_fakechord_elements(fakechord, curObj);
+	  DenemoObject *curObj =  (DenemoObject *) si->currentobject->data;
+	  //gchar *fakechord = cbdata->string;
+	  //separate_fakechord_elements(fakechord, curObj);
+	  if(((chord *) curObj->object)->fakechord)
+	    g_string_assign(((chord *) curObj->object)->fakechord, cbdata->string);
+	  else
+	    ((chord *) curObj->object)->fakechord = g_string_new(cbdata->string);
 	  do
 	    {
 	      if (si->currentobject->next)
-		cursorright (NULL);
+		movecursorright (NULL);
 	      else if (gui->si->currentmeasure->next)
-		measureright (NULL);
+		movetomeasureright (NULL);
 	      else 
 		break;
 	      curObj =
@@ -184,10 +187,9 @@ fakechord_insert (GtkAction *action, gpointer param)
  
   if (curObj && curObj->type == CHORD && ((chord *) curObj->object)->fakechord)
 	{
-		temp = g_string_append(temp, (((GString *) ((chord *) curObj->object)->fakechord)->str));
-		if (((chord *) curObj->object)->fakechord_extension != NULL)
-			temp = g_string_append(temp, (((GString *) ((chord *) curObj->object)->fakechord_extension)->str));
-		PreValue = temp->str;
+		
+		PreValue = (((GString *) ((chord *) curObj->object)->fakechord)->str);
+
 	}
 	
 
