@@ -24,7 +24,6 @@
 #include "exportmidi.h"
 #include "importxml.h"
 #include "importmusicxml.h"
-#include "exportcsound.h"
 #include "importmidi.h"
 
 #include "prefops.h"
@@ -79,9 +78,9 @@ static struct FileFormatData supported_file_formats[] = {/* WARNING this array h
   {"*.pdf", N_("PDF (*.pdf)"), ".pdf", 1},
   {"*.png", N_("PNG Image format (*.png)"), ".png", 1},
   {"*.abc", N_("ABC (*.abc)"), ".abc", 0},
-  {"*.mid", N_("Midi (*.mid)"), ".mid", 0},
+  {"*.mid", N_("Midi (*.mid, *.midi)"), ".mid", 0},
   {"*.sco", N_("CSound Score File (*.sco)"), ".sco", 0},
-  {"*.mxml", N_("MusicXML file (*.mxml)"), ".mxml", 0}
+  {"*.mxml", N_("MusicXML file (*.mxml, *.xml)"), ".mxml", 0}
 };
 
 static gchar* supported_denemo_file_extension[] = {
@@ -97,7 +96,7 @@ static gchar *supported_midi_file_extension[] = {
   "*.midi", "*.mid", "*.MIDI", "*.MID" 
 };
 static gchar *supported_musicxml_file_extension[] = {
-  "*.mxml", "*.MXML" 
+  "*.mxml", "*.MXML", "*.xml"
 };
 
 /* Some macros just to shorten lines */
@@ -357,9 +356,13 @@ open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, Impor
       gtk_signal_emit_by_name (GTK_OBJECT (Denemo.hadjustment), "changed");
       gtk_signal_emit_by_name (GTK_OBJECT (Denemo.vadjustment), "changed");
       force_lily_refresh(gui);
-    }
+    } else /*file load failed - gui may not be valid */
+    deletescore(NULL, gui);
+      
   g_signal_handlers_unblock_by_func(G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_expose_event), NULL);
   gui->si->undo_guard=1;
+
+
   denemo_scheme_init();//to re-instate any user defined directives for whole score
   gui->si->undo_guard=Denemo.prefs.disable_undo;//user pref to (dis)allow undo information to be collected
   return result;
@@ -420,7 +423,7 @@ save_in_format(gint format_id, DenemoGUI * gui, gchar *filename) {
     case PNG_FORMAT:
       {
 	gui->si->markstaffnum = 0;
-	export_png (file, FALSE, gui);
+	export_png (file, (GChildWatchFunc)printpng_finished, gui);
         break;
       };
     case ABC_FORMAT:
@@ -433,11 +436,6 @@ save_in_format(gint format_id, DenemoGUI * gui, gchar *filename) {
 	exportmidi (file, gui->si, 0, 0);
 	break;
       };
-    case CSOUND_FORMAT:
-      {
-	exportcsound (file, gui->si, 0, 0);
-	break;
-      };
     default:
       break;
     };
@@ -691,7 +689,70 @@ set_current_folder(GtkWidget *file_selection, DenemoGUI *gui, DenemoSaveType tem
     } 
 }
 
-#define FILE_DIALOG(message, format, save_type) \
+gchar *
+file_dialog(gchar *message, gboolean type, gchar *location){
+  GtkWidget *file_selection;
+  GtkFileFilter *filter;
+  gchar *filename;
+  file_selection = gtk_file_chooser_dialog_new (message,
+						GTK_WINDOW (Denemo.window),
+						type?
+						  GTK_FILE_CHOOSER_ACTION_OPEN:
+						  GTK_FILE_CHOOSER_ACTION_SAVE,
+						GTK_STOCK_CANCEL,
+						GTK_RESPONSE_REJECT,
+						type?
+						  GTK_STOCK_OPEN:
+						  GTK_STOCK_SAVE,
+						GTK_RESPONSE_ACCEPT, NULL);
+
+  if (location) 
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_selection),
+					   location);
+  gtk_dialog_set_default_response (GTK_DIALOG (file_selection),
+				   GTK_RESPONSE_ACCEPT);
+  gtk_widget_show_all (file_selection);
+  if (gtk_dialog_run (GTK_DIALOG (file_selection)) == GTK_RESPONSE_ACCEPT)
+    filename =
+	gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selection));
+  else
+    filename = NULL;
+  gtk_widget_destroy (file_selection);\
+  return filename;
+}
+
+static void
+update_preview_cb(GtkFileChooser *file_chooser, gpointer data){
+
+  GtkWidget *preview;
+  gchar *thumb_filename;
+  gchar *selection_filename;
+  GdkPixbuf *pixbuf;
+  gboolean have_preview;
+
+  preview = GTK_WIDGET(data);
+  selection_filename = gtk_file_chooser_get_preview_filename(file_chooser);
+  thumb_filename = large_thumbnail_name(selection_filename); 
+  pixbuf = gdk_pixbuf_new_from_file_at_size(thumb_filename, 512,512, NULL);
+  have_preview = (pixbuf !=NULL);
+  
+  printf("\n# %s for %s thumbnail = %s\n",have_preview? "We have a thumbnail generated":
+				     "We have not yet generated a thumbnail",
+ 				     selection_filename,
+				     thumb_filename);
+  
+  g_free(selection_filename);
+  g_free(thumb_filename);
+
+  gtk_image_set_from_pixbuf (GTK_IMAGE (preview), pixbuf);
+  if(pixbuf)
+    gdk_pixbuf_unref(pixbuf);
+  
+  gtk_file_chooser_set_preview_widget_active(file_chooser, have_preview);
+}
+
+
+#define FILE_OPEN_DIALOG(message, format, save_type) \
   gboolean ret = -1;\
   if(filename && !g_file_test(filename, G_FILE_TEST_IS_DIR))\
     return (open_for_real(filename, gui, template, type));\
@@ -719,6 +780,12 @@ set_current_folder(GtkWidget *file_selection, DenemoGUI *gui, DenemoSaveType tem
   gtk_dialog_set_default_response (GTK_DIALOG (file_selection),\
 				   GTK_RESPONSE_ACCEPT);\
   gtk_widget_show_all (file_selection);\
+  GtkWidget *preview;\
+  preview = gtk_image_new();\
+  gtk_file_chooser_set_preview_widget(GTK_FILE_CHOOSER (file_selection), preview);\
+  g_signal_connect (GTK_FILE_CHOOSER(file_selection), "update-preview",\
+			G_CALLBACK (update_preview_cb), preview);\
+  gtk_widget_show_all (preview);\
   if (gtk_dialog_run (GTK_DIALOG (file_selection)) == GTK_RESPONSE_ACCEPT)\
     {\
       gchar *name =\
@@ -741,7 +808,9 @@ set_current_folder(GtkWidget *file_selection, DenemoGUI *gui, DenemoSaveType tem
 static gint
 file_open (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar *filename)
 {
-  FILE_DIALOG("Open", denemo, DENEMO_FORMAT)
+  FILE_OPEN_DIALOG("Open", denemo, DENEMO_FORMAT)
+  if(getNumCharsSchemeText())
+	  executeScript(); 
 }
 
 /**
@@ -752,7 +821,7 @@ file_open (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar *fil
 static gint
 file_import_lilypond (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar *filename)
 {
-  FILE_DIALOG("Import Lilypond", lilypond, MUDELA_FORMAT)  
+  FILE_OPEN_DIALOG("Import Lilypond", lilypond, MUDELA_FORMAT)  
 }
 
 /**
@@ -763,7 +832,7 @@ file_import_lilypond (DenemoGUI * gui, DenemoSaveType template, ImportType type,
 static gint
 file_import_midi (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar *filename)
 {
-  FILE_DIALOG("Import Midi", midi, MIDI_FORMAT) 
+  FILE_OPEN_DIALOG("Import Midi", midi, MIDI_FORMAT) 
 }
 
 /**
@@ -774,7 +843,7 @@ file_import_midi (DenemoGUI * gui, DenemoSaveType template, ImportType type, gch
 static gint
 file_import_musicxml (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar *filename)
 {
-  FILE_DIALOG("Import MusicXML", musicxml, MUSICXML_FORMAT)
+  FILE_OPEN_DIALOG("Import MusicXML", musicxml, MUSICXML_FORMAT)
 }
 
 /**
@@ -851,7 +920,7 @@ file_save (GtkWidget * widget, DenemoGUI * gui)
   score_status(gui, FALSE);
 }
 
-#define FILE_DIALOG2(description)\
+#define FILE_SAVE_DIALOG(description)\
   GtkWidget *file_selection;\
   GtkWidget *label;\
   GtkWidget *hbox;\
@@ -904,7 +973,7 @@ file_export (DenemoGUI * gui, FileFormatNames format_id)
 {
   gchar *description = g_strconcat(_("Export As "), FORMAT_DESCRIPTION(format_id), NULL);
   DenemoSaveType  template = FALSE;
-  FILE_DIALOG2(description)
+  FILE_SAVE_DIALOG(description)
   g_free(description);
 }
 
@@ -917,7 +986,7 @@ void
 file_saveas (DenemoGUI * gui, DenemoSaveType  template)
 {
   gint format_id = DENEMO_FORMAT;
-  FILE_DIALOG2(_("Save As"))
+  FILE_SAVE_DIALOG(_("Save As"))
 }
 
 /**
@@ -943,6 +1012,7 @@ file_newwrapper (GtkAction * action, gpointer param)
     }
   //open_user_default_template(REPLACE_SCORE);
   load_initdotdenemo();
+  set_enharmonic_position(0);
   if(Denemo.printarea) 
     g_object_set_data(G_OBJECT(Denemo.printarea), "printviewupdate", (gpointer)G_MAXUINT);
 }
@@ -1138,14 +1208,3 @@ export_midi_action (GtkAction *action, DenemoScriptParam *param)
 {
   EXPORT_INTERFACE(MIDI_FORMAT)
 }
-
-/**
- * Export pdf callback prompts for filename
- *
- */
-void
-export_csound_action (GtkAction *action, DenemoScriptParam *param)
-{
-  EXPORT_INTERFACE(CSOUND_FORMAT)
-}
-
