@@ -144,7 +144,10 @@ gint  sfont_id = fluid_synth_sfload(synth, Denemo.prefs.fluidsynth_soundfont->st
   gint i;
   for(i=0;i<16;i++)
     fluid_synth_program_change(synth, i, 0);
-   return 0;
+  if(Denemo.prefs.pitchspellingchannel)
+    fluid_synth_program_change(synth, Denemo.prefs.pitchspellingchannel, Denemo.prefs.pitchspellingprogram);
+  set_tuning();
+  return 0;
 }                                                                                                                              
                     
 void fluidsynth_shutdown()
@@ -241,7 +244,8 @@ void fluid_output_midi_event(unsigned char *buffer)
 	 //return fluid_synth_channel_pressure(synth, chan,  event->midi_buffer[1]);
  
        case PITCH_BEND:
-         fluid_synth_pitch_bend(synth, chan, buffer[1] + (buffer[2]<<8)
+       g_print("LSB %d MSB %d so %d\n", buffer[1], buffer[2], buffer[2]<<7);
+         fluid_synth_pitch_bend(synth, chan, buffer[1] + (buffer[2]<<7)
 				       /*I think! fluid_midi_event_get_pitch(event)*/);
 	 break;
  
@@ -337,11 +341,9 @@ static gdouble GET_TIME (void) {
 //advance cursor to next note
 static void advance_clock(gchar *buf) {
   if(Denemo.gui->si->currentobject) {
-    DenemoScriptParam aparam;
-    DenemoScriptParam *param = &aparam;
     DenemoObject *obj = Denemo.gui->si->currentobject->data;
     if(obj->type!=CHORD) 
-      if(cursor_to_next_chord(param)) 
+      if(cursor_to_next_chord()) 
 	obj = Denemo.gui->si->currentobject->data;
     
     if(Denemo.gui->si->currentobject && obj->type==CHORD) {
@@ -352,13 +354,13 @@ static void advance_clock(gchar *buf) {
 	  gdouble thetime = get_time();
 	  Denemo.gui->si->start_player = thetime -  obj->earliest_time;
 	  
-	  if(thechord->is_tied && cursor_to_next_note(param)) {
+	  if(thechord->is_tied && cursor_to_next_note()) {
 	    obj = Denemo.gui->si->currentobject->data;	   
 	  }
 	  //playalong_time = obj->latest_time;
 	  //IF THE NEXT OBJ IS A REST ADVANCE OVER IT/THEM
 	  do {
-	    if(!cursor_to_next_note(param))	//if(!cursor_to_next_chord())	   	      
+	    if(!cursor_to_next_note())	//if(!cursor_to_next_chord())	   	      
 	      {
 		playalong_time = Denemo.gui->si->end_time + 1.0;
 		break;
@@ -479,7 +481,7 @@ static gboolean fluidsynth_play_smf_event(gchar *callback)
 	 //return fluid_synth_channel_pressure(synth, chan,  event->midi_buffer[1]);
  
        case PITCH_BEND:
-         fluid_synth_pitch_bend(synth, chan, event->midi_buffer[1] + (event->midi_buffer[2]<<8)
+         fluid_synth_pitch_bend(synth, chan, event->midi_buffer[1] + (event->midi_buffer[2]<<7)
 				       /*I think! fluid_midi_event_get_pitch(event)*/);
 	 break;
  
@@ -630,8 +632,10 @@ static void handle_midi_event(gchar *buf) {
       process_midi_event(buf);
     else
       if(Denemo.keyboard_state==(GDK_SHIFT_MASK) ||
-	 Denemo.keyboard_state==(GDK_LOCK_MASK))
-	fluid_output_midi_event(buf);
+	 Denemo.keyboard_state==(GDK_LOCK_MASK)) {
+	  adjust_midi_velocity(buf, 100 - Denemo.prefs.dynamic_compression);
+	  fluid_output_midi_event(buf);
+	 }
   }
 }
 
@@ -708,7 +712,7 @@ static handle_midi_event_func_t handle_midi_in(void* data, fluid_midi_event_t* e
   
     {
       short key = fluid_midi_event_get_pitch(event);
-      load_midi_buf(type, key>>8, key&0x7F);
+      load_midi_buf(type,  key&0x7F, key>>7);
     }
     break;
 
@@ -734,6 +738,7 @@ fluid_start_midi_in(void)
   int success = Denemo.prefs.fluidsynth_midi_driver->len?fluid_settings_setstr(settings, "midi.driver", Denemo.prefs.fluidsynth_midi_driver->str):0;
 #ifdef OSS_DRIVER
   success = fluid_settings_setstr(settings, "midi.driver", "oss");
+  success = fluid_settings_setstr(settings, "midi.oss.device", "/dev/midi1"); 
 #endif
   
 #ifdef ALSA_DRIVER
