@@ -31,7 +31,7 @@
 static gint version_number;
 
 
-static gint current_movement = 0, current_staff=0, current_measure=0, current_position = 0;
+static gint current_movement = 0, current_staff=0, current_measure=0, current_position = 0, tonal_center=0;
 
 /* Defines for making traversing XML trees easier */
 
@@ -292,7 +292,7 @@ parseDirective (xmlNodePtr parentElem, xmlNsPtr ns,
 }
 
 static gint
-parseWidgetDirective (xmlNodePtr parentElem, xmlNsPtr ns, gpointer fn, DenemoDirective *directive)
+parseWidgetDirective (xmlNodePtr parentElem, xmlNsPtr ns, gpointer fn, DenemoDirective *directive, GtkMenu *menu)
 {
   xmlNodePtr childElem;
   
@@ -315,10 +315,12 @@ parseWidgetDirective (xmlNodePtr parentElem, xmlNsPtr ns, gpointer fn, DenemoDir
     DO_INTDIREC(gy);
   }
   if(directive->tag==NULL)
-    directive->tag = g_string_new("<Unknown Tag>");
-
+	directive->tag = g_string_new("<Unknown Tag>");
+  if(directive->postfix && (g_str_has_prefix(directive->postfix->str, "tagline = \"Generated by Denemo Version"))) //drop old automated taglinesdirective->postfix->str
+	g_string_assign(directive->postfix, "");
   UPDATE_OVERRIDE(directive);
-  widget_for_directive(directive, fn);
+
+  widget_for_directive_menu(directive, fn, menu);
   return TRUE;
 }
 
@@ -354,6 +356,8 @@ fix_prefix_use(GList *directives) {
   GList *g;
   for(g=directives;g;g=g->next) {
     DenemoDirective *directive = g->data;
+    if(directive->tag==NULL)
+      directive->tag = g_string_new("<Unknown Tag>");
     if(directive->prefix) {
       directive->prefix = g_string_new(g_strdup_printf("%%{Disabled form \n%s\n use newer command %%}\n", directive->prefix->str));
       directive->display = g_string_new(g_strdup_printf("Warning - re-run the %s command here!\nold version", directive->tag->str));
@@ -374,14 +378,16 @@ parseDirectives (xmlNodePtr parentElem, xmlNsPtr ns)
 }
 
 static GList *
-parseWidgetDirectives (xmlNodePtr parentElem, xmlNsPtr ns, gpointer fn)
+parseWidgetDirectives (xmlNodePtr parentElem, xmlNsPtr ns, gpointer fn, GtkMenu*menu, GList **directives_pointer)
 {
   GList *directives = NULL;
   xmlNodePtr childElem;
   FOREACH_CHILD_ELEM (childElem, parentElem) {
     DenemoDirective *directive = (DenemoDirective*)g_malloc0(sizeof(DenemoDirective));
-    parseWidgetDirective(childElem, ns, fn, directive);
+    parseWidgetDirective(childElem, ns, fn, directive, menu);
     directives = g_list_append(directives, directive);
+    if(menu)
+	g_object_set_data(G_OBJECT(directive->widget), "directives-pointer", (gpointer)directives_pointer);//FIXME this const string has to match with lilydirectives.c
   }
   return directives;
 }
@@ -1186,6 +1192,33 @@ parseDecoration (xmlNodePtr decorationElem, DenemoObject * chordObj)
 }
 
 
+static GdkPixbuf *
+parseSource(xmlNodePtr parentElem, xmlNsPtr ns) {
+GError *error = NULL;
+gchar *cdata = xmlNodeListGetString (parentElem->doc, parentElem->xmlChildrenNode,1);
+gsize len;
+guchar *buf = g_base64_decode(cdata, &len);
+// xml free(cdata);
+GInputStream *is = g_memory_input_stream_new_from_data (buf, len, NULL);
+GdkPixbuf* pb = gdk_pixbuf_new_from_stream (is, NULL, &error);
+g_free(buf);
+return pb;
+}
+/**
+ * Parse the given sources element.
+ * 
+ * @param chordElem the XML node to process
+ * @param ns the Denemo XML namespaces
+ * @param sources the GList* to populate  */
+static GList *
+parseSources(xmlNodePtr parentElem, xmlNsPtr ns) {
+  GList *sources = NULL;
+  xmlNodePtr childElem;
+ FOREACH_CHILD_ELEM (childElem, parentElem)
+    sources = g_list_append(sources, parseSource(childElem, ns));
+  return sources;
+}
+
 /**
  * Parse the given <chord> element and return a chord-type DenemoObject.
  * 
@@ -1730,6 +1763,35 @@ parseGraceStart (xmlNodePtr graceStartElem, xmlNsPtr ns, DenemoScore * si)
   return result;
 }
 
+/**
+ * Parse the given <thumbnail> into the thumbnail  DenemoSelection.
+ * @param thumbElem the XML node to process
+ * @param ns the Denemo XML namespaces
+ * @param selection the DenemoSelection to populate 
+ * 
+ * @return 
+ */
+static void
+parseThumbElem (xmlNodePtr thumbElem, xmlNsPtr ns, DenemoSelection *selection)
+{
+   xmlNodePtr childElem;
+  FOREACH_CHILD_ELEM (childElem, thumbElem)
+  {
+     if (ELEM_NAME_EQ (childElem, "first-staff"))
+	selection->firststaffmarked = getXMLIntChild (childElem);
+	else      if (ELEM_NAME_EQ (childElem, "last-staff"))
+	selection->laststaffmarked = getXMLIntChild (childElem);
+	else if (ELEM_NAME_EQ (childElem, "first-measure"))
+	selection->firstmeasuremarked = getXMLIntChild (childElem);
+	else      if (ELEM_NAME_EQ (childElem, "last-measure"))
+	selection->lastmeasuremarked = getXMLIntChild (childElem);
+	else if (ELEM_NAME_EQ (childElem, "first-obj"))
+	selection->firstobjmarked = getXMLIntChild (childElem);
+	else      if (ELEM_NAME_EQ (childElem, "last-obj"))
+	selection->lastobjmarked = getXMLIntChild (childElem);
+  }	
+}
+
 
 /**
  * Parse the given <setup-info> element into the given score.
@@ -1805,7 +1867,7 @@ parseSetupInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoGUI * gui)
 	  }
 	else if (ELEM_NAME_EQ (childElem, "score-directives"))
 	  {
-	    gui->lilycontrol.directives = parseWidgetDirectives(childElem, ns, (gpointer)score_directive_put_graphic);
+	    gui->lilycontrol.directives = parseWidgetDirectives(childElem, ns, (gpointer)score_directive_put_graphic, NULL, NULL);
 	  }
 
 
@@ -1848,6 +1910,13 @@ parseEditInfo (xmlNodePtr editInfoElem, xmlNsPtr ns, DenemoScore * si)
 	    if(current_position<0)
 	      current_position = 0;
 	  }
+	else if (ELEM_NAME_EQ (childElem, "tonalcenter"))
+	  {
+	    tonal_center = getXMLIntChild (childElem);
+	    if(tonal_center<-7 || tonal_center>7)
+	      tonal_center = 0;
+	    set_enharmonic_position(tonal_center);
+	  }
 	else if (ELEM_NAME_EQ (childElem, "zoom"))
 	  {
 	    si->zoom = getXMLIntChild (childElem)/100.0;
@@ -1979,7 +2048,7 @@ parseScoreInfo (xmlNodePtr scoreInfoElem, xmlNsPtr ns, DenemoScore * si)
 		g_free (field);\
 	      }\
 	  }\
-
+//FIXME are these actually in use??? I think the fields are place in a <scoreheaders> element
 DO_ELEM("subtitle", 0)
 DO_ELEM("composer","HeaderComposer")
 DO_ELEM("poet","HeaderPoet")
@@ -1993,6 +2062,8 @@ DO_ELEM("head","HeaderHead")
 DO_ELEM("copyright","HeaderCopyright")
 DO_ELEM("footer","HeaderFooter")
 #undef DO_ELEM
+#if 0
+//drop support for this legacy setting of the tagline field
 	else if (ELEM_NAME_EQ (childElem, "tagline"))
 	  {
 	    tagline = (gchar *) xmlNodeListGetString (childElem->doc,
@@ -2000,12 +2071,13 @@ DO_ELEM("footer","HeaderFooter")
 						      xmlChildrenNode, 1);
 	    if (tagline != NULL)
 	      {
-		gchar *val = g_strdup_printf("tagline = \"%s\"\n", tagline);
+		gchar *val = g_strdup_printf("tagline = \"%s\"\n", tagline);		
 		scoreheader_directive_put_postfix("Scoretagline", val);
 		g_free(val);
 		g_free (tagline);
 	      }
 	  }
+#endif
 	else if (ELEM_NAME_EQ (childElem, "extra"))
 	  {
 	    mvmnt_header = (gchar *) xmlNodeListGetString (childElem->doc,
@@ -2081,8 +2153,9 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
   DenemoStaff *curStaff = (DenemoStaff *) si->currentprimarystaff->data;
 
   staffInfoElem = getXMLChild (staffElem, "staff-info", ns);
-  RETURN_IF_ELEM_NOT_FOUND ("staff", staffInfoElem, "staff-info");
-
+  //RETURN_IF_ELEM_NOT_FOUND ("staff", staffInfoElem, "staff-info");
+if(staffInfoElem==NULL) return 0;
+//rest is backward compatibility only
   FOREACH_CHILD_ELEM (childElem, staffInfoElem)
   {
     if (childElem->ns == ns)
@@ -2219,11 +2292,11 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
 	  }
 	else if (ELEM_NAME_EQ (childElem, "staff-directives"))
 	  {
-	    curStaff->staff_directives = parseWidgetDirectives(childElem, ns, (gpointer)staff_directive_put_graphic);
+	    curStaff->staff_directives = parseWidgetDirectives(childElem, ns, (gpointer)staff_directive_put_graphic, curStaff->staffmenu, &curStaff->staff_directives);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "voice-directives"))
 	  {
-	    curStaff->voice_directives = parseWidgetDirectives(childElem, ns, (gpointer)voice_directive_put_graphic);
+	    curStaff->voice_directives = parseWidgetDirectives(childElem, ns, (gpointer)voice_directive_put_graphic, curStaff->voicemenu, &curStaff->voice_directives);
 	  }
 	else if (ELEM_NAME_EQ (childElem, "clef-directives"))
 	  {
@@ -2267,6 +2340,112 @@ parseStaff (xmlNodePtr staffElem, xmlNsPtr ns, DenemoScore * si)
   return 0;
 }
 
+/**
+ * Parse the given <voice-info> element into the voice in the given score.
+ * @param voiceInfoElem the XML node to process
+ * @param ns the Denemo XML namespaces
+ * @param si the DenemoScore to populate 
+ * 
+ * @return 0 on success, -1 on failure
+ */
+static gint
+parseVoiceProps (xmlNodePtr voicePropElem, xmlNsPtr ns, DenemoScore *si)
+{
+  DenemoStaff *curStaff = (DenemoStaff *)si->currentstaff->data;
+  xmlNodePtr childElem;
+  FOREACH_CHILD_ELEM (childElem, voicePropElem)
+  {
+    if (ELEM_NAME_EQ (childElem, "number-of-lines"))
+	  {
+	    curStaff->no_of_lines = getXMLIntChild (childElem);
+	    if (curStaff->no_of_lines == G_MAXINT)
+	      {
+		g_warning ("Could not determine number of lines in staff; "
+			   "defaulting to 5");
+		curStaff->no_of_lines = 5;
+	      }
+	  }
+    else if (ELEM_NAME_EQ (childElem, "instrument"))
+	  {
+	    gchar *temp = (gchar *) xmlNodeListGetString
+	      (childElem->doc, childElem->xmlChildrenNode, 1);
+	    if(temp)
+	      g_string_assign (curStaff->midi_instrument, temp);
+	    else
+	      curStaff->midi_instrument = g_string_new("");
+	    g_free (temp);
+	  }
+    else if (ELEM_NAME_EQ (childElem, "volume"))
+	  {
+  	    curStaff->volume = getXMLIntChild (childElem);
+  	  }	    
+    else if (ELEM_NAME_EQ (childElem, "midi_prognum"))
+	  {
+  	    curStaff->midi_prognum = getXMLIntChild (childElem);
+  	  }
+	else if (ELEM_NAME_EQ (childElem, "midi_channel"))
+	  {
+  	    curStaff->midi_channel = getXMLIntChild (childElem);
+  	  }
+	else if (ELEM_NAME_EQ (childElem, "transpose"))
+	  {
+	    curStaff->transposition = getXMLIntChild (childElem);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "hasfigures"))
+	  {
+	    curStaff->hasfigures = getXMLIntChild (childElem);
+	    if(curStaff->hasfigures)
+	      si->has_figures = (gpointer) TRUE;
+	  }
+	else if (ELEM_NAME_EQ (childElem, "hasfakechords"))
+	  {
+	    curStaff->hasfakechords = getXMLIntChild (childElem);
+	    
+	  }
+	else if (ELEM_NAME_EQ (childElem, "verses"))
+	  {
+	    parseVerses(si, curStaff, childElem, ns);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "instrument"))
+	  {
+	    gchar *temp = (gchar *) xmlNodeListGetString
+	      (childElem->doc, childElem->xmlChildrenNode, 1);
+	    if(temp)
+	      g_string_assign (curStaff->midi_instrument, temp);
+	    else
+	      curStaff->midi_instrument = g_string_new("");
+	    g_free (temp);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "device-port"))
+	  {
+	    gchar *temp = (gchar *) xmlNodeListGetString
+	      (childElem->doc, childElem->xmlChildrenNode, 1);
+	    if(temp)
+	      g_string_assign (curStaff->device_port, temp);
+	    else
+	      curStaff->device_port = g_string_new("");
+	    g_free (temp);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "staff-directives"))
+	  {
+	    curStaff->staff_directives = parseWidgetDirectives(childElem, ns, (gpointer)staff_directive_put_graphic, curStaff->staffmenu, &curStaff->staff_directives);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "voice-directives"))
+	  {
+	    curStaff->voice_directives = parseWidgetDirectives(childElem, ns, (gpointer)voice_directive_put_graphic, curStaff->voicemenu, &curStaff->voice_directives);
+	  }
+	else if (ELEM_NAME_EQ (childElem, "clef-directives"))
+	  {
+	    curStaff->clef.directives = parseDirectives(childElem, ns);
+	  }
+	else
+	  {
+	    ILLEGAL_ELEM ("staff-info", childElem);
+	  }
+      }
+return 0;
+}
+
 
 /**
  * Parse the given <voice-info> element into the voice in the given score.
@@ -2408,6 +2587,13 @@ parseInitVoiceParams (xmlNodePtr initVoiceParamsElem, xmlNsPtr ns,
 	  {
 	    parseTimeSignature (childElem, ns, &curVoice->timesig);
 	  }
+
+	else if (ELEM_NAME_EQ (childElem, "sources"))
+	  {
+	    curVoice->sources = parseSources (childElem, ns);
+	  }
+
+	  
 	else
 	  {
 	    ILLEGAL_ELEM ("initial-voice-params", childElem);
@@ -2719,7 +2905,12 @@ parseVoice (xmlNodePtr voiceElem, xmlNsPtr ns, DenemoGUI * gui)
   RETURN_IF_ELEM_NOT_FOUND ("voice", childElem, "initial-voice-params");
   if (parseInitVoiceParams (childElem, ns, si) != 0)
     return -1;
-
+    
+  childElem = getXMLChild (voiceElem, "voice-props", ns);
+  if(childElem) //older files will not have this
+    if (parseVoiceProps (childElem, ns, si) != 0)
+      return -1;
+    
   childElem = getXMLChild (voiceElem, "measures", ns);
   RETURN_IF_ELEM_NOT_FOUND ("voice", childElem, "measures");
   if (parseMeasures (childElem, ns, si) != 0)
@@ -2763,15 +2954,21 @@ parseScore (xmlNodePtr scoreElem, xmlNsPtr ns, DenemoGUI * gui, ImportType type)
 
   childElem = getXMLChild (scoreElem, "header-directives", ns);
   if (childElem != 0)
-    si->header.directives = parseWidgetDirectives(childElem, ns, (gpointer)header_directive_put_graphic);
+    si->header.directives = parseWidgetDirectives(childElem, ns, (gpointer)header_directive_put_graphic, NULL, NULL);
 
   childElem = getXMLChild (scoreElem, "layout-directives", ns);
   if (childElem != 0)
-    si->layout.directives = parseWidgetDirectives(childElem, ns, (gpointer)layout_directive_put_graphic);
+    si->layout.directives = parseWidgetDirectives(childElem, ns, (gpointer)layout_directive_put_graphic, NULL, NULL);
 
   childElem = getXMLChild (scoreElem, "movementcontrol-directives", ns);
   if (childElem != 0)
-    si->movementcontrol.directives = parseWidgetDirectives(childElem, ns, (gpointer)movementcontrol_directive_put_graphic);
+    si->movementcontrol.directives = parseWidgetDirectives(childElem, ns, (gpointer)movementcontrol_directive_put_graphic, NULL, NULL);
+
+  childElem = getXMLChild (scoreElem, "sources", ns);
+  if (childElem != 0)
+    si->sources = parseSources(childElem, ns);//puts the pixbufs after decode_base64 into a GList* at this location
+
+    
 
   childElem = getXMLChild (scoreElem, "score-info", ns);
   RETURN_IF_ELEM_NOT_FOUND ("score", childElem, "score-info");
@@ -2825,6 +3022,10 @@ static gint   parseMovement(xmlNodePtr childElem, xmlNsPtr ns, DenemoGUI *gui, I
    ret = parseScore (childElem, ns, gui, type);
    sPrevStaffElem = NULL;
    staffnode *curstaff;
+  if(si->thescore==NULL) {
+    g_warning("Bad Denemo file\n");
+    return -1;
+   }
   for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
     {
       beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
@@ -2993,12 +3194,15 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
 	  } else
 	    if (ELEM_NAME_EQ (childElem, "lilycontrol")){
 	      parseSetupInfo(childElem, ns, gui);
+	    } else
+	      if (ELEM_NAME_EQ (childElem, "thumbnail")){
+	      parseThumbElem (childElem, ns, &gui->thumbnail);
 	    } else
 	      if (ELEM_NAME_EQ (childElem, "scoreheader-directives")){
-		gui->scoreheader.directives = parseWidgetDirectives(childElem, ns, (gpointer)scoreheader_directive_put_graphic);
+		gui->scoreheader.directives = parseWidgetDirectives(childElem, ns, (gpointer)scoreheader_directive_put_graphic, NULL, NULL);
 	      } else
 		if (ELEM_NAME_EQ (childElem, "paper-directives")){
-		  gui->paper.directives = parseWidgetDirectives(childElem, ns, (gpointer)paper_directive_put_graphic);
+		  gui->paper.directives = parseWidgetDirectives(childElem, ns, (gpointer)paper_directive_put_graphic, NULL, NULL);
 		} else
 		  if (ELEM_NAME_EQ (childElem, "custom_scoreblock")){
 		    gchar *tmp = (gchar *) xmlNodeListGetString (childElem->doc,
@@ -3034,8 +3238,7 @@ importXML (gchar * filename, DenemoGUI *gui, ImportType type)
     gtk_widget_hide(gui->si->lyricsbox);
       }
 	
-	if(getNumCharsSchemeText())
-	  executeScript(); 
+
 	break;
       default:
 	warningdialog("Erroneous call");
