@@ -217,9 +217,9 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar *fallbac
 	    name = 
 	      xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
 	    menupaths = NULL;//We allow multiple menupaths for a given action, all are added to the gtk_ui when this command is processed after the tooltip node. This is very bad xml, as the action should have all the others as children, and not depend on the order.FIXME
-#ifdef DEBUG
+#if 0
 	    g_print ("Action %s\n", (gchar *) name);
-#endif /*DEBUG*/
+#endif
 	  }
       } else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "scheme")) {
 	scheme = 
@@ -900,6 +900,7 @@ parseMenu(xmlNodePtr rootElem, gchar *path, DenemoGUI *gui ) {
 	    g_object_set_data(G_OBJECT(widget), "menupath", g_strdup(path));
 	  }
        }
+       g_free (name);
       }
     }
   return 0;
