@@ -122,8 +122,11 @@ gint
 scorearea_keyrelease_event (GtkWidget * widget, GdkEventKey * event)
 {
   Denemo.keyboard_state ^= (0xf & klock_mask(event->keyval));
-  if((event->keyval==GDK_Alt_L)||(event->keyval==GDK_Alt_R))
+  if((event->keyval==GDK_Alt_L)||(event->keyval==GDK_Alt_R)) {
+    if((Denemo.keyboard_state&CHORD_MASK))//At least one note has been entered in a chord
+      next_editable_note();
     Denemo.keyboard_state &= ~CHORD_MASK;
+  }
   set_midi_in_status();
   // g_print("release %x state %x\n", Denemo.keyboard_state, event->state);
   // set_cursor_for(keyrelease_modify(event->state), event->keyval);
@@ -145,8 +148,10 @@ gchar* perform_command(const gchar *command_name, GdkEventKey *event) {
   execute_callback_from_name(Denemo.map, command_name);
   call_out_to_guile("(define DenemoKeypressActivatedCommand #f)");
   // note gui = Denemo.gui; may have changed as a result of executing the command
-  if(Denemo.gui->si)
-    displayhelper (Denemo.gui);
+#ifndef TESTING_REPEATED_XPOSITION_UPDATE
+ if(Denemo.gui->si)
+ displayhelper(Denemo.gui);
+#endif
   return NULL;
 }
 
@@ -853,6 +858,21 @@ flatten_key (DenemoGUI * gui)
   else
     incrementenshift (gui, -1);
 }
+void
+pending_sharpen (DenemoGUI * gui)
+{
+  Denemo.gui->si->pending_enshift++;
+  if(Denemo.gui->si->pending_enshift>2)
+    Denemo.gui->si->pending_enshift = 2;
+}
+void
+pending_flatten (DenemoGUI * gui)
+{
+  Denemo.gui->si->pending_enshift--;
+  if(Denemo.gui->si->pending_enshift<-2)
+    Denemo.gui->si->pending_enshift = -2;
+}
+
 void
 stem_down (DenemoGUI * gui)
 {
