@@ -139,7 +139,7 @@ new_directive(gchar *tag){
 }
 
 
-static  DenemoObject *findobj(void) {
+static  DenemoObject *get_object(void) {
   DenemoGUI *gui = Denemo.gui;
   DenemoScore * si = gui->si;
   return (DenemoObject *) si->currentobject ?
@@ -160,7 +160,7 @@ attach_directive (attach_type attach, gchar *postfix, gchar *prefix, gchar *disp
   DenemoGUI *gui = Denemo.gui;
   DenemoScore * si = gui->si;
   note *curnote = NULL;
-  DenemoObject *curObj = findobj();
+  DenemoObject *curObj = get_object();
   if(curObj==NULL) {  
     if(interactive)
       warningdialog("You must put the cursor on a chord to attach LilyPond");//FIXME find a note and ask
@@ -420,7 +420,7 @@ chord_directive (GtkAction *action, DenemoScriptParam *param)
 
 static DenemoObject *get_chordobject(void) {
   chord *thechord = NULL;
-  DenemoObject *curObj = findobj();
+  DenemoObject *curObj = get_object();
   if(curObj==NULL)
     return NULL;
   thechord = (chord *)curObj->object;
@@ -464,7 +464,7 @@ static DenemoStaff *get_staff(void) {
 //block for new type of directive
 static  clef *get_clef(void) {
   clef *ret = NULL;
-  DenemoObject *curObj = findobj();  
+  DenemoObject *curObj = get_object();  
   if(curObj && curObj->type==CLEF){
     ret = ((clef*)curObj->object);
   } else {
@@ -495,7 +495,7 @@ gboolean delete_clef_directive(gchar *tag) {
 
 static  keysig *get_keysig(void) {
   keysig *ret = NULL;
-  DenemoObject *curObj = findobj();  
+  DenemoObject *curObj = get_object();  
   if(curObj && curObj->type==KEYSIG){
     ret = ((keysig*)curObj->object);
   } else {
@@ -524,7 +524,7 @@ gboolean delete_keysig_directive(gchar *tag) {
 
 static  timesig *get_timesig(void) {
   timesig *ret = NULL;
-  DenemoObject *curObj = findobj();  
+  DenemoObject *curObj = get_object();  
   if(curObj && curObj->type==TIMESIG){
     ret = ((timesig*)curObj->object);
   } else {
@@ -553,7 +553,7 @@ gboolean delete_timesig_directive(gchar *tag) {
 
 static  tuplet *get_tuplet(void) {
   tuplet *ret = NULL;
-  DenemoObject *curObj = findobj();  
+  DenemoObject *curObj = get_object();  
   if(curObj && (curObj->type==TUPOPEN || curObj->type==TUPCLOSE)){
     ret = ((tuplet*)curObj->object);
   }
@@ -578,7 +578,7 @@ gboolean delete_tuplet_directive(gchar *tag) {
 
 static  stemdirective *get_stemdirective(void) {
   stemdirective *ret = NULL;
-  DenemoObject *curObj = findobj();  
+  DenemoObject *curObj = get_object();  
   if(curObj && (curObj->type==STEMDIRECTIVE)){
     ret = ((stemdirective*)curObj->object);
   }
@@ -724,6 +724,23 @@ DenemoObject *curObj = get_chordobject();
   return find_directive(thechord->directives, tag);
 }
 
+static
+DenemoDirective *get_object_directive(gchar *tag) {
+DenemoObject *curObj = get_object();
+  if(curObj==NULL)
+    return NULL;
+  if(curObj->directives==NULL)
+    return NULL;
+  return find_directive(curObj->directives, tag);
+}
+gboolean delete_object_directive(gchar *tag) {
+  DenemoObject *curObj = get_object();
+  if(curObj==NULL)
+    return FALSE;
+  if(curObj->directives==NULL)
+    return FALSE;
+  return delete_directive(&curObj->directives, tag);
+}
 static
 DenemoDirective *get_score_directive(gchar *tag) {
 
@@ -838,7 +855,7 @@ what##_directive_get_##field(gchar *tag) {\
 typedef DenemoStaff staff;
 typedef DenemoStaff voice;
 typedef DenemoLilyControl score;
-
+typedef DenemoObject object;
 
 
      //note I think you cannot change the graphic once you have set it.
@@ -872,7 +889,6 @@ PUT_GRAPHIC(tuplet)
 PUT_GRAPHIC(stemdirective)
 
 
-
 #define PUT_STR_FIELD_FUNC_NAME(what, field, name)\
 gboolean \
 what##_directive_put_##field(gchar *tag, gchar *value) {\
@@ -902,7 +918,7 @@ what##_directive_put_##field(gchar *tag, gchar *value) {\
 
 
 
-
+GET_TAG_FUNC(object);
 GET_TAG_FUNC(standalone);
 GET_TAG_FUNC(chord);
 GET_TAG_FUNC(note);
@@ -1021,8 +1037,9 @@ what##_directive_get_##field(gchar *tag) {\
   return 0;\
 }
 
-
-
+PUT_GRAPHIC(object)
+PUT_INT_FIELD_FUNC(object, minpixels)
+GET_INT_FIELD_FUNC(object, minpixels)
 
      /* block which can be copied for new int fields */
 PUT_INT_FIELD_FUNC(note, minpixels)
@@ -1369,7 +1386,7 @@ if directive is non-DenemoObject directive it  places the widget in the appropri
 */
      
 void 
-widget_for_directive_menu(DenemoDirective *directive,  void fn(), GtkMenu *staffmenu, GtkMenu *voicemenu) {
+widget_for_directive_menu(DenemoDirective *directive,  void fn(), GtkMenu *menu) {
   GtkWidget *box;
   gchar *value = "";
   //FIXME we don't need value now...
@@ -1393,24 +1410,12 @@ widget_for_directive_menu(DenemoDirective *directive,  void fn(), GtkMenu *staff
 	box = NULL;
 
 
-    if(fn==(void(*)())staff_directive_put_graphic) {
-      //g_print("Doing the staff case");
-      /* g_print("directive-type %s.....", thetype);	*/
-      GtkWidget *menu;
-      menu = GTK_WIDGET(staffmenu);
-      directive->widget = gtk_menu_item_new_with_label(value);
-      attach_textedit_widget(directive);
-      g_signal_connect(G_OBJECT(directive->widget), "button-release-event",  G_CALLBACK(button_callback), directive);
-      gtk_menu_shell_prepend(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
-    } else    
-      if(fn==(void(*)())voice_directive_put_graphic) {
-	//g_print("Doing the voice case");
-	directive->widget = GTK_WIDGET(gtk_menu_item_new_with_label(value));//WARNING _with_label is important
-	attach_textedit_widget(directive);
-	GtkWidget *menu;
-	menu = GTK_WIDGET(voicemenu);  
-	g_signal_connect(G_OBJECT(directive->widget), "button-release-event",  G_CALLBACK(button_callback), directive);
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
+    if((fn==(void(*)())staff_directive_put_graphic) || (fn==(void(*)())voice_directive_put_graphic)) {
+	//g_print("Doing the staff or voice case");
+        directive->widget = GTK_WIDGET(gtk_menu_item_new_with_label(value));//WARNING _with_label is important
+        attach_textedit_widget(directive);	
+        g_signal_connect(G_OBJECT(directive->widget), "button-release-event",  G_CALLBACK(button_callback), directive);
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), GTK_WIDGET(directive->widget));
       }  else 
 	if(box)  {
 	  //g_print("Doing the score and movement cases starting from %p", directive->widget);
@@ -1447,36 +1452,37 @@ widget_for_directive_menu(DenemoDirective *directive,  void fn(), GtkMenu *staff
 }
 void 
 widget_for_directive(DenemoDirective *directive,  void fn()) {
-GtkMenu *staffmenu=NULL, *voicemenu=NULL;
+GtkMenu *menu=NULL;
  if(Denemo.gui->si){
-   if( (fn == (void(*)())staff_directive_put_graphic) || (fn==(void(*)())voice_directive_put_graphic)) {
-   staffmenu =  ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->staffmenu;
-   voicemenu =  ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->voicemenu;
-   }
+    if(fn == (void(*)())staff_directive_put_graphic) {
+        menu =  ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->staffmenu;
+    }
+    if(fn==(void(*)())voice_directive_put_graphic) {
+        menu =  ((DenemoStaff*)Denemo.gui->si->currentstaff->data)->voicemenu;
+    }    
  }
-   
-  widget_for_directive_menu(directive, fn, staffmenu, voicemenu);
+  widget_for_directive_menu(directive, fn, menu);
 }
 void
 widget_for_staff_directive(DenemoDirective *directive, GtkMenu *menu) {
-  return widget_for_directive_menu(directive, (void(*)())staff_directive_put_graphic, menu, NULL);
+  return widget_for_directive_menu(directive, (void(*)())staff_directive_put_graphic, menu);
 }
 void
 widget_for_voice_directive(DenemoDirective *directive, GtkMenu *menu) {
-  return widget_for_directive_menu(directive, (void(*)())voice_directive_put_graphic, NULL, menu);
+  return widget_for_directive_menu(directive, (void(*)())voice_directive_put_graphic,  menu);
 }
 
 void
 widget_for_movementcontrol_directive(DenemoDirective *directive) {
-  return widget_for_directive_menu(directive, (void(*)())movementcontrol_directive_put_graphic, NULL, NULL);
+  return widget_for_directive_menu(directive, (void(*)())movementcontrol_directive_put_graphic, NULL);
 }
 void
 widget_for_header_directive(DenemoDirective *directive) {
-  return widget_for_directive_menu(directive, (void(*)())header_directive_put_graphic, NULL, NULL);
+  return widget_for_directive_menu(directive, (void(*)())header_directive_put_graphic,  NULL);
 }
 void
 widget_for_layout_directive(DenemoDirective *directive) {
-  return widget_for_directive_menu(directive, (void(*)())layout_directive_put_graphic, NULL, NULL);
+  return widget_for_directive_menu(directive, (void(*)())layout_directive_put_graphic, NULL);
 }
 
 // create a directive for non-DenemoObject directive #what
@@ -1770,7 +1776,7 @@ standalone_directive_put_minpixels(gchar *tag, gint value) {
   DenemoDirective *directive = get_standalone_directive(tag);
   if(directive){
     directive->minpixels = value;//This field is not actually useful for standalone directives.
-    DenemoObject *obj = findobj();
+    DenemoObject *obj = get_object();
     store_for_undo_change (Denemo.gui->si, obj);
     obj->minpixelsalloted = value;
   }
@@ -1976,7 +1982,7 @@ gboolean unpopulate_menu(GtkWidget *menu) {
 
 
 void edit_object(GtkAction *action,  DenemoScriptParam *param) {
-  DenemoObject *obj = findobj();
+  DenemoObject *obj = get_object();
   if(obj==NULL){
       warningmessage("No object here to edit");
     return;
@@ -2051,9 +2057,12 @@ static void create_script(DenemoDirective *directive, gchar *what) {
   GString *scheme = g_string_new(directive->tag->str);
   g_string_prepend(scheme, ";;;");
   g_string_append(scheme, "\n");
-
+if(what==NULL) {
+  what = "standalone";
+  g_string_append_printf(scheme, "(d-DirectivePut-standalone \"%s\")", directive->tag->str);
+}
 #define ADD_TEXT(field)\
-if(directive->field)\
+if(directive->field && directive->field->len)\
   {gchar *quote = quote_scheme(directive->field->str);\
    g_string_append_printf(scheme, "(d-DirectivePut-%s-%s \"%s\" \"%s\")\n",\
        what, #field, directive->tag->str, quote);\
@@ -2230,10 +2239,12 @@ static gboolean text_edit_directive(DenemoDirective *directive, gchar *what) {
   button = gtk_button_new_with_label("Put Edit Script");
   gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
   g_signal_connect(G_OBJECT(button),"clicked",  G_CALLBACK(put_edit_script), directive->tag->str);
-
+#if 0
+//disabled until website can take uploading again
   button = gtk_button_new_with_label("Upload Edit Script");
   gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
   g_signal_connect(G_OBJECT(button),"clicked",  G_CALLBACK(upload_edit_script_cb), directive->tag->str);
+#endif  
   button = gtk_check_button_new_with_label("Show Current Script");
   gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
   gtk_action_connect_proxy(gtk_ui_manager_get_action (Denemo.ui_manager, "/MainMenu/ViewMenu/ToggleScript"), button);
@@ -2256,6 +2267,7 @@ static gboolean text_edit_directive(DenemoDirective *directive, gchar *what) {
   else {
     clone->widget = NULL;//prevent any button being destroyed FIXME ???
     free_directive(clone);
+    score_status(Denemo.gui, TRUE);
   }
 #define REMOVEEMPTIES(field)\
 if(directive->field && directive->field->len==0) g_string_free(directive->field, TRUE), directive->field=NULL;
@@ -2314,7 +2326,11 @@ edit_directive(DenemoDirective *directive, gchar *what) {
   gboolean ret = TRUE;
   gchar* filename = get_editscript_filename(directive->tag->str);
   if(filename == NULL) {
-    ret =( text_edit_directive(directive, what)  || !confirm("Directive Delete", "Are you sure you want to delete the directive?"));
+    GtkAction *action = lookup_action_from_name (directive->tag->str);
+    if(action)
+      activate_script(action, NULL);
+    else
+      ret =( text_edit_directive(directive, what)  || !confirm("Directive Delete", "Are you sure you want to delete the directive?"));
     score_status (Denemo.gui, TRUE);
     return ret;
   }
@@ -2356,7 +2372,7 @@ void edit_object_directive(GtkAction *action,  DenemoScriptParam *param) {
 /**
  * callback for DeleteDirective 
  */
-void delete_object_directive(GtkAction *action,  DenemoScriptParam *param) {
+void delete_chord_or_note_directive(GtkAction *action,  DenemoScriptParam *param) {
   //g_print("Edit directive called\n");
   DenemoDirective *directive;
   GList **directives;
