@@ -326,7 +326,7 @@ settickvalsinmeasure (objnode * theobjs)
 			in_tuplet = TRUE;
 			numerator = ((tupopen *) theobj->object)->numerator;
 			denominator = ((tupopen *) theobj->object)->denominator;
-			basic_ticks_in_tuplet_group = 0;	/* Probably gratuitous */
+			/* basic_ticks_in_tuplet_group = 0; does not work when nested tuplets are used */
 		}
 		else if (theobj->type == TUPCLOSE)
 		{
@@ -456,7 +456,7 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1,
   gint next_stem_directive = *stem_directive;
   gboolean isbeambreak;
 
-#ifdef DEBUG
+#if 0
   {static gint count = 0;
   count++;
   gint stem = *stem_directive;
