@@ -217,7 +217,8 @@ void safely_track_remove_from_smf(smf_track_t *track) {
  * @enshift enharmonic adjustment -1 is one flat etc.. 
  * @octave
  */
-static void action_note_into_score (DenemoGUI *gui, gint mid_c_offset, gint enshift, gint octave) {
+static void action_note_into_score (gint mid_c_offset, gint enshift, gint octave) {
+  DenemoGUI *gui = Denemo.gui;
   gui->last_source = INPUTMIDI;
   gui->si->cursor_y = gui->si->staffletter_y = mid_c_offset;
   gui->si->cursor_y += 7*octave; 
@@ -225,7 +226,8 @@ static void action_note_into_score (DenemoGUI *gui, gint mid_c_offset, gint ensh
   setenshift(gui->si, enshift);
   displayhelper (gui);
 }
-static void add_note_to_chord (DenemoGUI *gui, gint mid_c_offset, gint enshift, gint octave) {
+static void add_note_to_chord (gint mid_c_offset, gint enshift, gint octave) {
+  DenemoGUI *gui = Denemo.gui;
   gui->last_source = INPUTMIDI;
   gui->si->cursor_y = gui->si->staffletter_y = mid_c_offset;
   gui->si->cursor_y += 7*octave; 
@@ -256,20 +258,82 @@ void record_midi(gchar *buf, gdouble time) {
 }
 
 static void 	      
-do_one_note(DenemoGUI *gui, gint mid_c_offset, gint enshift, gint notenum) {
-  
+do_one_note(gint mid_c_offset, gint enshift, gint notenum) {
+  DenemoGUI *gui = Denemo.gui;
   if((Denemo.keyboard_state&ADDING_MASK) && (Denemo.keyboard_state&CHORD_MASK)) {
     
-    add_note_to_chord(gui, mid_c_offset, enshift, notenum);
+    add_note_to_chord(mid_c_offset, enshift, notenum);
   }
   else {
-    action_note_into_score(gui, mid_c_offset, enshift, notenum);
+    DenemoObject *curobj = NULL;
+    //check for non-printing notes - back up to the first non-printing note.
+    gboolean non_printing_note = FALSE;
+    PushPosition(NULL, NULL);
+    while(cursor_to_prev_note()) {
+      curobj=Denemo.gui->si->currentobject->data;
+      if(!curobj->isinvisible)
+	break;
+      else
+	non_printing_note = TRUE;
+    }
+    if(Denemo.gui->si->currentobject) {
+        curobj=Denemo.gui->si->currentobject->data;
+        if(non_printing_note) {
+        if(!curobj->isinvisible)
+            cursor_to_next_note();
+        pop_position();
+        } else 
+        PopPosition(NULL, NULL);
+    }   
+    action_note_into_score(mid_c_offset, enshift, notenum);
     if(Denemo.keyboard_state&ADDING_MASK)
       Denemo.keyboard_state |= CHORD_MASK;
     set_midi_in_status();
   }
 }
 
+static gboolean get_current(enharmonic *enote) {
+  DenemoObject *curObj=NULL;
+   if(Denemo.gui->si->currentobject) {
+    curObj = Denemo.gui->si->currentobject->data;
+    if(curObj && curObj->type==CHORD) {
+      chord *thechord = (chord *)  curObj->object;
+      if(thechord->notes) {
+        note *thenote = (note *) thechord->notes->data;
+          enote->mid_c_offset = offsettonumber(thenote->mid_c_offset);
+          enote->enshift = thenote->enshift;
+          return TRUE;
+      }
+    }
+   }
+return FALSE;
+}
+
+static gboolean get_previous(enharmonic *enote) {
+  DenemoObject *curObj=NULL;
+   if(Denemo.gui->si->currentobject) {
+     if(Denemo.gui->si->currentobject->prev) 
+      curObj = Denemo.gui->si->currentobject->prev->data;
+      else {
+      if(Denemo.gui->si->currentmeasure->prev && Denemo.gui->si->currentmeasure->prev->data) {
+        curObj = g_list_last(Denemo.gui->si->currentmeasure->prev->data)->data;
+      }
+    }
+   }
+  if(curObj && curObj->type==CHORD) {
+    chord *thechord = (chord *)  curObj->object;
+    if(thechord->notes) {
+        note *thenote = (note *) thechord->notes->data;
+        enote->mid_c_offset = offsettonumber(thenote->mid_c_offset);
+        enote->enshift = thenote->enshift;
+        return TRUE;
+      }
+    }
+return FALSE;
+}
+
+
+
 /*  take an action for the passed note. Enter/edit/check the score following the mode and keyboard state. */
 static gint midiaction(gint notenum) {
 
@@ -277,27 +341,20 @@ static gint midiaction(gint notenum) {
   if(gui==NULL)
     return TRUE;
   if(gui->si==NULL)
-
     return TRUE;
-  //gint notenum;
   DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
-  // notenum = get_midi_note();
-  // if(notenum < 0) 
-  //  return TRUE;
-  enharmonic enote;
+  enharmonic enote, prevenote;
+  gboolean have_previous;
   //g_print("Keyboard state %x, mask %x %x %x\n", Denemo.keyboard_state, CHECKING_MASK, GDK_CONTROL_MASK, GDK_MOD2_MASK);
   notenum2enharmonic (notenum, &enote.mid_c_offset, &enote.enshift, &enote.octave);
-  if( !(Denemo.keyboard_state&CHECKING_MASK)) {
-    if(Denemo.prefs.immediateplayback) {
-      if (Denemo.prefs.midi_audio_output == Portaudio)
-	playpitch(midi2hz(notenum), 0.3, 0.5, 0);
-      if (Denemo.prefs.midi_audio_output == Jack)
-	jack_playpitch(notenum, 300 /*duration*/);
-      else if (Denemo.prefs.midi_audio_output == Fluidsynth)
-	fluid_playpitch(notenum, 300 /*duration*/,  curstaffstruct->midi_channel, 0);
-    }
-    stage_undo(gui->si, ACTION_STAGE_END);//undo is a queue so this is the end :)
-  }
+  if(Denemo.gui->si->cursor_appending)
+    have_previous = get_current(&prevenote);
+  else
+    have_previous = get_previous(&prevenote);
+    
+  if( !(Denemo.keyboard_state&CHECKING_MASK))
+   stage_undo(gui->si, ACTION_STAGE_END);//undo is a queue so this is the end :)
+
   if((gui->mode & INPUTEDIT) || (Denemo.keyboard_state&CHECKING_MASK))
     {
       static gboolean beep = FALSE;
@@ -327,7 +384,7 @@ static gint midiaction(gint notenum) {
 	    }
 	    else {
 
-	      do_one_note(gui, enote.mid_c_offset, enote.enshift, enote.octave);
+	      do_one_note(enote.mid_c_offset, enote.enshift, enote.octave);
 		
 	    }
 	    if(Denemo.gui->si->cursor_appending)
@@ -335,7 +392,7 @@ static gint midiaction(gint notenum) {
 	  } while((!(Denemo.keyboard_state&ADDING_MASK)) && next_editable_note() && is_tied);
 	} else {
 	  if(gui->si->cursor_appending)
-	    do_one_note(gui, enote.mid_c_offset, enote.enshift, enote.octave);
+	    do_one_note(enote.mid_c_offset, enote.enshift, enote.octave);
 	  else
 	    gdk_beep();
 	}
@@ -346,19 +403,31 @@ static gint midiaction(gint notenum) {
 	  else if(beep) signal_measure_end(), beep=FALSE;
 	}
       } else {// no current object
-	//	if((Denemo.keyboard_state&ADDING_MASK))
-	// add_note_to_chord(gui, enote.mid_c_offset, enote.enshift, notenum/12 - 5);
-	  //else
-	  //action_note_into_score(gui, enote.mid_c_offset, enote.enshift, notenum/12 - 5);
-	  do_one_note(gui, enote.mid_c_offset, enote.enshift, enote.octave);
+	  do_one_note(enote.mid_c_offset, enote.enshift, enote.octave);
       }
     } else {// not INPUTEDIT    
-      action_note_into_score(gui, enote.mid_c_offset, enote.enshift, enote.octave);
+      action_note_into_score(enote.mid_c_offset, enote.enshift, enote.octave);
   }
   if( !(Denemo.keyboard_state&CHECKING_MASK)) {
     stage_undo(gui->si, ACTION_STAGE_START);
   }
   gtk_widget_queue_draw (Denemo.scorearea);//just for advancing the cursor.
+ if(!(Denemo.keyboard_state&CHECKING_MASK)) {
+    if(Denemo.prefs.immediateplayback) {
+      gint channel = curstaffstruct->midi_channel;
+      
+      if(have_previous && check_interval(enote.mid_c_offset, enote.enshift, prevenote.mid_c_offset, prevenote.enshift))
+        channel = Denemo.prefs.pitchspellingchannel;
+              
+      if (Denemo.prefs.midi_audio_output == Portaudio)
+        playpitch(midi2hz(notenum), 0.3, 0.5, 0);
+      if (Denemo.prefs.midi_audio_output == Jack)
+        jack_playpitch(notenum, 300 /*duration*/);
+      else if (Denemo.prefs.midi_audio_output == Fluidsynth)
+        fluid_playpitch(notenum, 300 /*duration*/,  channel, 0);
+    }
+  }
+
   return TRUE;
 }
 
@@ -385,9 +454,17 @@ gboolean set_midi_capture(gboolean set) {
   return ret;
 }
 
+
 #define command ((*buf)&0xF0)
 #define notenumber ((*(buf+1))&0x7F)
 #define velocity ((*(buf+2))&0x7F)
+void
+adjust_midi_velocity(gchar *buf, gint percent) {
+  if(command==MIDI_NOTEON)
+    buf[2]=127 - (gint)((127-buf[2])*percent/100.0);
+} 
+
+
 void process_midi_event(gchar *buf) {
   //g_print("process midi (%s) %x %x %x\n",divert_midi_event?"diverted":"straight", command, notenumber, velocity);
   if(divert_midi_event &&  divert_midi_id==Denemo.gui->id){
@@ -404,17 +481,7 @@ void process_midi_event(gchar *buf) {
     buf[2]=128;//FIXME 127
   }
 #endif  
-   if (command==MIDI_CTL_CHANGE && (notenumber == 0x40)){
-	if (velocity == 0x7F)
-	  //PEDAL DOWN
-	  Denemo.keyboard_state |= ADDING_MASK;
-	else {
-	  Denemo.keyboard_state &= ~(CHORD_MASK|ADDING_MASK);
-	  next_editable_note();
-	}
-	set_midi_in_status();
-	displayhelper(Denemo.gui);
-      }
+ 
 
 
   if(midi_capture_on) {
@@ -427,17 +494,27 @@ void process_midi_event(gchar *buf) {
       midiaction(notenumber);
     else if(command==MIDI_CTL_CHANGE) {
       gchar *command_name = get_midi_control_command(notenumber, velocity);
-      if(command_name)
-      //FIXME what sort of free? g_free(command_name);
-	execute_callback_from_name(Denemo.map, command_name);
-
+      if(command_name) {  
+        execute_callback_from_name(Denemo.map, command_name);
+        g_free(command_name);
+      } else {
+        if (notenumber == 0x40){  //Foot Pedal
+          if (velocity == 0x7F) {
+            Denemo.keyboard_state |= ADDING_MASK;
+        } else {
+            Denemo.keyboard_state &= ~(CHORD_MASK|ADDING_MASK);
+            next_editable_note();
+        }
+        set_midi_in_status();
+        displayhelper(Denemo.gui);
+        }
+      } 
     } else if(command==MIDI_PITCH_BEND) {
       gchar *command_name = get_midi_pitch_bend_command((notenumber<<8) + velocity);
-      if(command_name)
-      //FIXME what sort of free? g_free(command_name);
-	execute_callback_from_name(Denemo.map, command_name);
-
-      ;//the same
+      if(command_name) {
+        execute_callback_from_name(Denemo.map, command_name);
+      g_free(command_name);
+      }
     }
   }
 }
