@@ -198,8 +198,10 @@ get_placement_from_coordinates (struct placement_info *pi,
       pi->measure_number++;
     }
   //g_print("got to measure %d\n", pi->measure_number);
-  pi->nextmeasure = (x_to_explain > GPOINTER_TO_INT (mwidthiterator->data)
-		     && pi->measure_number >= rightmeasurenum);
+  pi->nextmeasure = (
+		     (si->system_height>0.5 || x_to_explain > GPOINTER_TO_INT (mwidthiterator->data))
+		      && 
+pi->measure_number >= rightmeasurenum);
     
   pi->the_staff = g_list_nth (si->thescore, pi->staff_number - 1);
   pi->the_measure
@@ -370,6 +372,30 @@ scorearea_leave_event(GtkWidget *widget, GdkEventCrossing *event) {
    return FALSE;//allow other handlers (specifically the pitch entry one)
 }
 
+gint 
+scorearea_enter_event(GtkWidget *widget, GdkEventCrossing *event) {
+//g_print("start the enter with ks = %x and state %x\n", Denemo.keyboard_state, event->state);
+	if(event->state&GDK_CONTROL_MASK) 
+	Denemo.keyboard_state |= GDK_CONTROL_MASK;
+	 else
+	Denemo.keyboard_state &= ~GDK_CONTROL_MASK;
+
+	if(event->state&GDK_SHIFT_MASK) 
+	Denemo.keyboard_state |= GDK_SHIFT_MASK;
+	 else
+	Denemo.keyboard_state &= ~GDK_SHIFT_MASK;
+#if 0
+//perhaps it would be better to clear Denemo.keyboard_state on focus out event???
+	if(event->state&GDK_MOD1_MASK) 
+	Denemo.keyboard_state |= GDK_MOD1_MASK;
+	 else
+	Denemo.keyboard_state &= ~(CHORD_MASK|GDK_MOD1_MASK);
+#endif
+//	g_print("end the enter with ks %x (values  %x %x)\n", event->state, ~GDK_CONTROL_MASK, Denemo.keyboard_state & (~GDK_CONTROL_MASK) );
+	set_midi_in_status();
+   return FALSE;//allow other handlers 
+}
+
 /**
  * Mouse motion callback 
  *
@@ -495,11 +521,6 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
   gtk_widget_grab_focus(widget);
   gint key = gui->si->maxkeywidth;
   gint cmajor = key?0:5;//allow some area for keysig in C-major
-  if(left && (gui->si->leftmeasurenum>1) && (event->x<KEY_MARGIN+SPACE_FOR_TIME+key)  && (event->x>LEFT_MARGIN)){
-    set_currentmeasurenum (gui, gui->si->leftmeasurenum-1);
-    gtk_widget_queue_draw (Denemo.scorearea);
-    return TRUE;
-  } 
 
   if(gui->lefts[line_num] == 0)
     return TRUE;//On an empty system at the bottom where there is not enough room to draw another staff.
@@ -514,7 +535,19 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
     return TRUE;//could not place the cursor
   change_staff(gui->si, pi.staff_number, pi.the_staff);
 
-
+  
+  if(left && (gui->si->leftmeasurenum>1) && (event->x<KEY_MARGIN+SPACE_FOR_TIME+key)  && (event->x>LEFT_MARGIN)){
+    moveto_currentmeasurenum(gui, gui->si->leftmeasurenum-1); 
+    write_status(gui);
+    gtk_widget_queue_draw (Denemo.scorearea);
+    return TRUE;
+  } 
+  else
+    if(pi.nextmeasure) {
+      moveto_currentmeasurenum(gui, gui->si->rightmeasurenum+1);
+      write_status(gui);
+     
+    }
 
 
   if (pi.the_measure != NULL){ /*don't place cursor in a place that is not there*/
@@ -529,8 +562,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
       (gui->si->cursor_x ==
        (gint) (g_list_length ((objnode *) gui->si->currentmeasure->data)));
     set_cursor_y_from_click (gui, event->y);
-    if(pi.nextmeasure)
-      movetomeasureright(NULL); 
+
     write_status(gui);
   }
 
@@ -568,6 +600,9 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
     //  calcmarkboundaries (gui->si);
      lh_down = TRUE;
  
+  } else {
+    if(gui->si->cursor_appending)
+    movecursorleft(NULL);//so that right click in appending position acts on previous object
   }
   /* Redraw to show new cursor position, note a real draw is needed because of side effects on display*/
   gtk_widget_draw (Denemo.scorearea, NULL);
