@@ -1,8 +1,9 @@
-/* prefdialog.cpp
+/* prefdialog.c
  * functions for a preferences dialog
  *
  * for Denemo, a gtk+ frontend to GNU Lilypond
- * (c) 1999-2005 Matthew Hiller, Adam Tee */
+ * (c) 1999-2005 Matthew Hiller, Adam Tee, 2011 Richard Shann */
+
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -28,6 +29,8 @@ struct callbackdata
   GtkWidget *lilypath;
   GtkWidget *midi_audio_output;
   GtkWidget *immediateplayback;
+  GtkWidget *pitchspellingchannel;
+  GtkWidget *pitchspellingprogram;
   GtkWidget *modal;
   GtkWidget *cursor_highlight;
   GtkWidget *persistence;
@@ -58,6 +61,7 @@ struct callbackdata
   GtkWidget *password;
   GtkWidget *sequencer;
   GtkWidget *midi_in;
+  GtkWidget *dynamic_compression;
 
   GtkWidget *zoom;
   GtkWidget *system_height;
@@ -81,11 +85,13 @@ struct callbackdata
   GtkWidget *profile;
   GtkWidget *midiplayer;
   GtkWidget *audioplayer;
+  GtkWidget *fontspec;
   GtkWidget *denemopath;
   GtkWidget *temperament;
   GtkWidget *strictshortcuts;
   GtkWidget *resolution;
   GtkWidget *overlays;
+  GtkWidget *enable_thumbnails;
   GtkWidget *continuous;
 };
 
@@ -145,7 +151,8 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNTEXT(username)
   ASSIGNTEXT(password)
   ASSIGNTEXT(profile)
-  ASSIGNTEXT(audioplayer)
+
+  ASSIGNTEXT(fontspec)
   ASSIGNTEXT(denemopath)
     // ASSIGNTEXT(sequencer)
 #ifndef _HAVE_FLUIDSYNTH_
@@ -172,10 +179,11 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNTEXT(temperament)
   ASSIGNBOOLEAN(strictshortcuts)
   ASSIGNBOOLEAN(overlays)
+  ASSIGNBOOLEAN(enable_thumbnails)
   ASSIGNBOOLEAN(continuous)
   ASSIGNINT(resolution)
   ASSIGNINT(maxhistory)
-
+  ASSIGNINT(dynamic_compression)
   ASSIGNINT(zoom)
   ASSIGNINT(system_height)
 
@@ -183,6 +191,8 @@ set_preferences (struct callbackdata *cbdata)
   ASSIGNCOMBO2(midi_audio_output); 
   
   ASSIGNBOOLEAN(immediateplayback)
+  ASSIGNINT(pitchspellingchannel)
+  ASSIGNINT(pitchspellingprogram)
   ASSIGNBOOLEAN(modal)
   ASSIGNBOOLEAN(persistence)
   ASSIGNBOOLEAN(cursor_highlight)
@@ -433,6 +443,7 @@ preferences_change (GtkAction *action, gpointer param)
   TEXTENTRY("Image Viewer", imageviewer)
 
   TEXTENTRY("Audio Player", audioplayer)
+  TEXTENTRY("Default Font Specification", fontspec)
 
   TEXTENTRY("Default Save Path", denemopath)
   BOOLEANENTRY("Update the command set on startup", autoupdate);
@@ -446,7 +457,7 @@ preferences_change (GtkAction *action, gpointer param)
   INTENTRY_LIMITS(_("Page Turn Steps"), animation_steps, 1, 200);
 
   INTENTRY_LIMITS(_("Excerpt Resolution"), resolution, 72, 600);
-
+  BOOLEANENTRY("Enable Thumbnails", enable_thumbnails);
   INTENTRY(_("Max recent files"), maxhistory)
   TEXTENTRY("User Name", username)
   PASSWORDENTRY("Password for Denemo.org", password)
@@ -486,9 +497,12 @@ preferences_change (GtkAction *action, gpointer param)
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   }
 
-  BOOLEANENTRY("Play back entered notes immediately", immediateplayback);   
+  BOOLEANENTRY("Play back entered notes immediately", immediateplayback);
+  INTENTRY_LIMITS(_("Pitch Spelling Channel"), pitchspellingchannel, 0, 15);
+  INTENTRY_LIMITS(_("Pitch Spelling Program"), pitchspellingprogram, 0, 127);
+    
   BOOLEANENTRY("Auto-start midi in", startmidiin);
-
+  INTENTRY_LIMITS(_("% MIDI-in Dynamic Compression"), dynamic_compression, 1, 100);
   COMBOBOX("Midi/Audio output", midi_audio_output, output_option_list, Denemo.prefs.midi_audio_output)
   g_signal_connect(G_OBJECT(GTK_COMBO(midi_audio_output)->entry), "changed",
   G_CALLBACK( GTK_SIGNAL_FUNC(midi_audio_tab_update) ), &audio_cbdata);
