@@ -39,9 +39,7 @@ readxmlprefsFile (gchar * filename);
  *
  * .denemo/ is used for holding configuration files, templates, and so on.
  *
- * I suspect that this may have some Windows portability issues,
- * but I'm not sure on this. 
- *
+ * On windows the home directory is the one containing the My Documents folder.
  */
 
 const gchar *
@@ -52,7 +50,7 @@ locatedotdenemo ()
   gboolean err;
   if (!dotdenemo)
     {
-      dotdenemo = g_build_filename (g_get_home_dir(), ".denemo", NULL);
+      dotdenemo = g_build_filename (g_get_home_dir(), ".denemo-"PACKAGE_VERSION, NULL);
     }
   err = g_mkdir_with_parents(dotdenemo, 0770);
   if(err) {
@@ -64,6 +62,15 @@ locatedotdenemo ()
   return dotdenemo;
 }
 
+/* return a path to a temporary directory to be used for print intermediate files */
+const gchar *
+locateprintdir (void)
+{
+  static gchar *printdir = NULL;
+  if (!printdir)
+    printdir = make_temp_dir();
+  return printdir;
+}
 
 /**
  * Initialise user preferences to reasonable defaults 
@@ -83,10 +90,6 @@ initprefs ()
 
   ret->mode = INPUTEDIT|INPUTRHYTHM|INPUTNORMAL;
 
-
-  ret->csoundcommand = g_string_new ("csound -dm6");
-
-  ret->csoundorcfile = g_string_new ("");
   const gchar *name = g_get_user_name();
   ret->username = g_string_new (name?name:"DenemoUser");
   ret->password = g_string_new ("");
@@ -103,7 +106,7 @@ initprefs ()
 #ifdef _HAVE_FLUIDSYNTH_ 
   ret->midi_audio_output = Fluidsynth;	  
 #endif
-
+  ret->fontspec = g_string_new ("Denemo 9");
 #ifdef G_OS_WIN32
   ret->browser = g_string_new ("");//use file association
   ret->midiplayer = g_string_new ("");
@@ -123,7 +126,7 @@ initprefs ()
 #endif /* !G_OS_WIN32 */
   ret->sequencer = g_string_new ("/dev/sequencer");
   ret->midi_in = g_string_new ("/dev/midi");
-
+  ret->profile = g_string_new("");
   ret->denemopath = g_string_new (g_get_home_dir());
   ret->lilyversion = g_string_new ("");//meaning use installed LilyPond version
   ret->temperament = g_string_new("Equal");
@@ -153,7 +156,8 @@ initprefs ()
   gchar *soundfontpath = g_build_filename (get_data_dir (), "soundfonts",
 		                                           "A320U.sf2", NULL);
   ret->fluidsynth_soundfont = g_string_new(soundfontpath);
-
+  ret->pitchspellingchannel = 15;
+  ret->pitchspellingprogram = 17;
 
 #ifdef G_OS_WIN32
   ret->fluidsynth_sample_rate = 22050;//the worst case slow machine
@@ -162,10 +166,9 @@ initprefs ()
 #endif
 #endif
   ret->saveparts = FALSE;
-  ret->rtcs = TRUE;
-  ret->playbackoutput = FALSE;
   ret->lilyentrystyle = FALSE;
   ret->createclones = FALSE;
+  ret->enable_thumbnails = TRUE;
   ret->autosave = TRUE;
   ret->autosave_timeout = 5;
   ret->maxhistory = 20;
@@ -417,7 +420,9 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	}
 
 	READXMLENTRY(midiplayer)      
-	READXMLENTRY(audioplayer)        
+	READXMLENTRY(audioplayer)
+	READXMLENTRY(fontspec)
+	       
 	READXMLENTRY(browser)
         else if (0 ==
 	       xmlStrcmp (cur->name, (const xmlChar *) "autosavetimeout"))
@@ -448,14 +453,12 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 	      xmlFree (tmp);
 	    }
 	}
-      READXMLENTRY(csoundcommand)
-      READXMLENTRY(csoundorcfile)
 	
-      READBOOLXMLENTRY(rtcs)
       READBOOLXMLENTRY(autosave)
       
       READXMLENTRY(pdfviewer)
-      READXMLENTRY(imageviewer)    
+      READXMLENTRY(imageviewer) 
+         
       READXMLENTRY(profile) 
 	
       READXMLENTRY(username)    
@@ -467,7 +470,9 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READXMLENTRY2(midi_audio_output)
       
       READBOOLXMLENTRY(createclones)
-      READBOOLXMLENTRY(immediateplayback) 
+      READBOOLXMLENTRY(immediateplayback)
+      READINTXMLENTRY(pitchspellingchannel)
+      READINTXMLENTRY(pitchspellingprogram) 
       READBOOLXMLENTRY(modal) 
       READBOOLXMLENTRY(persistence) 
       READBOOLXMLENTRY(cursor_highlight) 
@@ -481,6 +486,8 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READDOUBLEXMLENTRY(display_refresh)
       READINTXMLENTRY(animation_steps)
       READBOOLXMLENTRY(overlays)
+      READBOOLXMLENTRY(enable_thumbnails)
+      
       READBOOLXMLENTRY(continuous)
       READBOOLXMLENTRY(jacktransport)
       READBOOLXMLENTRY(jacktransport_start_stopped)
@@ -505,6 +512,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READINTXMLENTRY(fluidsynth_sample_rate)
       READINTXMLENTRY(fluidsynth_period_size)
       READINTXMLENTRY(zoom)
+      READINTXMLENTRY(dynamic_compression)
       READINTXMLENTRY(system_height)
 
 
@@ -569,6 +577,7 @@ parseHistory (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 
 	      g_queue_push_tail (prefs->history, g_strdup(file));
 	      g_free (tmp);
+	      g_free (file);
 	    }
 	}
 
@@ -770,8 +779,8 @@ writeXMLPrefs (DenemoPrefs * prefs)
 
   WRITEXMLENTRY(midiplayer)
   WRITEXMLENTRY(audioplayer)
-  WRITEXMLENTRY(csoundcommand)
-  WRITEXMLENTRY(csoundorcfile)  
+  WRITEXMLENTRY(fontspec)
+
   WRITEXMLENTRY(pdfviewer)
   WRITEXMLENTRY(imageviewer)
   WRITEXMLENTRY(profile)
@@ -823,6 +832,8 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEBOOLXMLENTRY(createclones)
   WRITEBOOLXMLENTRY(lilyentrystyle)
   WRITEBOOLXMLENTRY(immediateplayback)
+  WRITEINTXMLENTRY(pitchspellingchannel)
+  WRITEINTXMLENTRY(pitchspellingprogram)
   WRITEBOOLXMLENTRY(modal)
   WRITEBOOLXMLENTRY(persistence)
   WRITEBOOLXMLENTRY(cursor_highlight)
@@ -835,14 +846,14 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEDOUBLEXMLENTRY(display_refresh)
   WRITEINTXMLENTRY(animation_steps)
   WRITEBOOLXMLENTRY(overlays)
+  WRITEBOOLXMLENTRY(enable_thumbnails)
   WRITEBOOLXMLENTRY(continuous)
   WRITEBOOLXMLENTRY(jacktransport)
   WRITEBOOLXMLENTRY(jacktransport_start_stopped)
-  WRITEINTXMLENTRY(rtcs)
-    WRITEBOOLXMLENTRY(toolbar)
+  WRITEBOOLXMLENTRY(toolbar)
   WRITEBOOLXMLENTRY(notation_palette)
-    WRITEBOOLXMLENTRY(midi_in_controls)
-    WRITEBOOLXMLENTRY(playback_controls)
+  WRITEBOOLXMLENTRY(midi_in_controls)
+  WRITEBOOLXMLENTRY(playback_controls)
   WRITEBOOLXMLENTRY(articulation_palette)
   WRITEBOOLXMLENTRY(console_pane)
   WRITEBOOLXMLENTRY(lyrics_pane)
@@ -858,6 +869,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
   WRITEBOOLXMLENTRY(fluidsynth_chorus)
   WRITEINTXMLENTRY(fluidsynth_sample_rate)
   WRITEINTXMLENTRY(fluidsynth_period_size)
+  WRITEINTXMLENTRY(dynamic_compression)
   WRITEINTXMLENTRY(zoom)
   WRITEINTXMLENTRY(system_height)
 
@@ -888,7 +900,10 @@ readHistory ()
       filename = g_string_new (locatedotdenemo ());
       g_string_append (filename, "/denemohistory");
     }
-  doc = xmlParseFile (filename->str);
+  if(g_file_test(filename->str, G_FILE_TEST_EXISTS))
+    doc = xmlParseFile (filename->str);
+  else
+    return ret;
 
   if (doc == NULL)
     {
