@@ -12,8 +12,8 @@
 #define INITIAL_WIDTH 1000
 #define INITIAL_HEIGHT 500
 
-const gchar *locatedotdenemo ();
-
+const gchar *locatedotdenemo (void);
+const gchar *locateprintdir (void);
 void initprefs (void);
 gint readxmlprefsString (gchar * xmlprefs);
 gint writeXMLPrefs( DenemoPrefs *prefs);
