@@ -155,6 +155,34 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "OneHundredTwentyEighthNot
 SCM scheme_TwoHundredFiftySixthNote(SCM optional);
 install_scm_function ("d-TwoHundredFiftySixthNote", scheme_TwoHundredFiftySixthNote);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "TwoHundredFiftySixthNote")), "scm", (gpointer)1);
+/*InsertWholeRest insert_rest_0key*/
+SCM scheme_InsertWholeRest(SCM optional);
+install_scm_function ("d-InsertWholeRest", scheme_InsertWholeRest);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertWholeRest")), "scm", (gpointer)1);
+/*InsertHalfRest insert_rest_1key*/
+SCM scheme_InsertHalfRest(SCM optional);
+install_scm_function ("d-InsertHalfRest", scheme_InsertHalfRest);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertHalfRest")), "scm", (gpointer)1);
+/*InsertQuarterRest insert_rest_2key*/
+SCM scheme_InsertQuarterRest(SCM optional);
+install_scm_function ("d-InsertQuarterRest", scheme_InsertQuarterRest);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertQuarterRest")), "scm", (gpointer)1);
+/*InsertEighthRest insert_rest_3key*/
+SCM scheme_InsertEighthRest(SCM optional);
+install_scm_function ("d-InsertEighthRest", scheme_InsertEighthRest);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertEighthRest")), "scm", (gpointer)1);
+/*InsertSixteenthRest insert_rest_4key*/
+SCM scheme_InsertSixteenthRest(SCM optional);
+install_scm_function ("d-InsertSixteenthRest", scheme_InsertSixteenthRest);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertSixteenthRest")), "scm", (gpointer)1);
+/*InsertThirtysecondRest insert_rest_5key*/
+SCM scheme_InsertThirtysecondRest(SCM optional);
+install_scm_function ("d-InsertThirtysecondRest", scheme_InsertThirtysecondRest);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertThirtysecondRest")), "scm", (gpointer)1);
+/*InsertSixtyfourthRest insert_rest_6key*/
+SCM scheme_InsertSixtyfourthRest(SCM optional);
+install_scm_function ("d-InsertSixtyfourthRest", scheme_InsertSixtyfourthRest);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertSixtyfourthRest")), "scm", (gpointer)1);
 /*InsertBlankWholeNote insert_blankchord_0key*/
 SCM scheme_InsertBlankWholeNote(SCM optional);
 install_scm_function ("d-InsertBlankWholeNote", scheme_InsertBlankWholeNote);
@@ -199,34 +227,6 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ToggleRestMode")), "scm",
 SCM scheme_ToggleBlankMode(SCM optional);
 install_scm_function ("d-ToggleBlankMode", scheme_ToggleBlankMode);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ToggleBlankMode")), "scm", (gpointer)1);
-/*InsertWholeRest insert_rest_0key*/
-SCM scheme_InsertWholeRest(SCM optional);
-install_scm_function ("d-InsertWholeRest", scheme_InsertWholeRest);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertWholeRest")), "scm", (gpointer)1);
-/*InsertHalfRest insert_rest_1key*/
-SCM scheme_InsertHalfRest(SCM optional);
-install_scm_function ("d-InsertHalfRest", scheme_InsertHalfRest);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertHalfRest")), "scm", (gpointer)1);
-/*InsertQuarterRest insert_rest_2key*/
-SCM scheme_InsertQuarterRest(SCM optional);
-install_scm_function ("d-InsertQuarterRest", scheme_InsertQuarterRest);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertQuarterRest")), "scm", (gpointer)1);
-/*InsertEighthRest insert_rest_3key*/
-SCM scheme_InsertEighthRest(SCM optional);
-install_scm_function ("d-InsertEighthRest", scheme_InsertEighthRest);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertEighthRest")), "scm", (gpointer)1);
-/*InsertSixteenthRest insert_rest_4key*/
-SCM scheme_InsertSixteenthRest(SCM optional);
-install_scm_function ("d-InsertSixteenthRest", scheme_InsertSixteenthRest);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertSixteenthRest")), "scm", (gpointer)1);
-/*InsertThirtysecondRest insert_rest_5key*/
-SCM scheme_InsertThirtysecondRest(SCM optional);
-install_scm_function ("d-InsertThirtysecondRest", scheme_InsertThirtysecondRest);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertThirtysecondRest")), "scm", (gpointer)1);
-/*InsertSixtyfourthRest insert_rest_6key*/
-SCM scheme_InsertSixtyfourthRest(SCM optional);
-install_scm_function ("d-InsertSixtyfourthRest", scheme_InsertSixtyfourthRest);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "InsertSixtyfourthRest")), "scm", (gpointer)1);
 /*InsertDuplet insert_duplet*/
 SCM scheme_InsertDuplet(SCM optional);
 install_scm_function ("d-InsertDuplet", scheme_InsertDuplet);
@@ -275,6 +275,14 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Sharpen")), "scm", (gpoin
 SCM scheme_Flatten(SCM optional);
 install_scm_function ("d-Flatten", scheme_Flatten);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Flatten")), "scm", (gpointer)1);
+/*PendingSharpen pending_sharpen*/
+SCM scheme_PendingSharpen(SCM optional);
+install_scm_function ("d-PendingSharpen", scheme_PendingSharpen);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PendingSharpen")), "scm", (gpointer)1);
+/*PendingFlatten pending_flatten*/
+SCM scheme_PendingFlatten(SCM optional);
+install_scm_function ("d-PendingFlatten", scheme_PendingFlatten);
+g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PendingFlatten")), "scm", (gpointer)1);
 /*StemUp stem_up*/
 SCM scheme_StemUp(SCM optional);
 install_scm_function ("d-StemUp", scheme_StemUp);
@@ -987,10 +995,6 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ExportPNG")), "scm", (gpo
 SCM scheme_ExportMIDI(SCM optional);
 install_scm_function ("d-ExportMIDI", scheme_ExportMIDI);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ExportMIDI")), "scm", (gpointer)1);
-/*ExportCSOUND export_csound_action*/
-SCM scheme_ExportCSOUND(SCM optional);
-install_scm_function ("d-ExportCSOUND", scheme_ExportCSOUND);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "ExportCSOUND")), "scm", (gpointer)1);
 /*ConfigureScore scorewizard*/
 SCM scheme_ConfigureScore(SCM optional);
 install_scm_function ("d-ConfigureScore", scheme_ConfigureScore);
@@ -1235,7 +1239,7 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditTimesigDirective")),
 SCM scheme_EditKeysigDirective(SCM optional);
 install_scm_function ("d-EditKeysigDirective", scheme_EditKeysigDirective);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "EditKeysigDirective")), "scm", (gpointer)1);
-/*DeleteDirective delete_object_directive*/
+/*DeleteDirective delete_chord_or_note_directive*/
 SCM scheme_DeleteDirective(SCM optional);
 install_scm_function ("d-DeleteDirective", scheme_DeleteDirective);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "DeleteDirective")), "scm", (gpointer)1);
@@ -1291,10 +1295,6 @@ g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Play")), "scm", (gpointer
 SCM scheme_Stop(SCM optional);
 install_scm_function ("d-Stop", scheme_Stop);
 g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "Stop")), "scm", (gpointer)1);
-/*PlayCSound csoundplayback*/
-SCM scheme_PlayCSound(SCM optional);
-install_scm_function ("d-PlayCSound", scheme_PlayCSound);
-g_object_set_data(G_OBJECT(action_of_name(Denemo.map, "PlayCSound")), "scm", (gpointer)1);
 /*PlaybackProperties playback_properties_change*/
 SCM scheme_PlaybackProperties(SCM optional);
 install_scm_function ("d-PlaybackProperties", scheme_PlaybackProperties);
