@@ -297,6 +297,7 @@ next_movement (GtkAction *action, DenemoScriptParam *param)
   update_vscrollbar (gui);
   gtk_signal_emit_by_name (GTK_OBJECT (Denemo.hadjustment), "changed");
   gtk_signal_emit_by_name (GTK_OBJECT (Denemo.vadjustment), "changed");
+  write_status(gui);
   gtk_widget_draw (Denemo.scorearea, NULL);//KLUDGE FIXME see staffup/down
 }
 
@@ -339,7 +340,8 @@ prev_movement (GtkAction *action, DenemoScriptParam *param)
   gtk_widget_queue_draw (Denemo.scorearea);
   gtk_signal_emit_by_name (GTK_OBJECT (Denemo.hadjustment), "changed");
   gtk_signal_emit_by_name (GTK_OBJECT (Denemo.vadjustment), "changed");
- gtk_widget_draw (Denemo.scorearea, NULL);//KLUDGE FIXME see staffup/down
+  write_status(gui);
+  gtk_widget_draw (Denemo.scorearea, NULL);//KLUDGE FIXME see staffup/down
 }
 /**
  * Initialise scoreinfo structure 
@@ -473,6 +475,10 @@ DenemoScore * clone_movement(DenemoScore *si) {
 
   GList *g;
   newscore->measurewidths = NULL;
+  if(newscore->sources) {
+    g_warning("Undo will lose source screenshots\n");
+    newscore->sources = NULL;
+  }
   for(g=si->measurewidths;g;g=g->next)
     newscore->measurewidths = g_list_append(newscore->measurewidths, g->data);
   newscore->playingnow = NULL;
