@@ -53,5 +53,33 @@ draw_slur (cairo_t * cr, GSList ** slur_stack,
       cairo_move_to( cr, x1, y - 15 );
       cairo_rel_curve_to( cr, (x2-x1)/3, -8, (x2-x1)*2/3, -8, (x2-x1), 0 );
       cairo_stroke( cr );
-    }
+    } else {
+    cairo_set_line_width( cr, 1.0 );
+    cairo_move_to( cr, 0, y - 15 );
+    cairo_rel_curve_to( cr, (x2)/3, -8, (x2)*2/3, -8, (x2), 0 );
+    cairo_stroke( cr );
+  }
+}
+
+void
+draw_slur_start (cairo_t * cr,
+	   gint x, gint y)
+{
+
+    cairo_set_line_width( cr, 1.0 );
+    cairo_move_to( cr, x, y - 15 );
+    cairo_rel_line_to( cr, 8, -4 );
+    cairo_stroke( cr );
+ 
+}
+void
+draw_slur_end (cairo_t * cr,
+	   gint x, gint y)
+{
+
+    cairo_set_line_width( cr, 1.0 );
+    cairo_move_to( cr, x, y - 15 );
+    cairo_rel_line_to( cr, -8, -4 );
+    cairo_stroke( cr );
+ 
 }
