@@ -206,6 +206,22 @@ insert_staff (DenemoScore * si, DenemoStaff * thestaffstruct,
 
 }
 
+//CREATE a GtkMenus to popup when clicking to left of the staff
+GtkMenu * create_menu(GList *directives) {
+    //hmm, cannot populate it, why not ? FIXME 
+    GtkWidget *item;
+    //thestaffstruct->staffmenu = 
+      return (GtkMenu *)gtk_menu_new();
+    //item = gtk_menu_item_new_with_label("Edit Attributes");
+    //gtk_menu_shell_append(GTK_MENU_SHELL( thestaffstruct->staffmenu), item);
+    //g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(edit_staff_directive), NULL);
+    //gtk_widget_show(item);
+    //thestaffstruct->voicemenu = (GtkMenu *)gtk_menu_new();
+    //item = gtk_menu_item_new_with_label("Edit Attributes");
+    //gtk_menu_shell_append(GTK_MENU_SHELL( thestaffstruct->voicemenu), item);
+    //g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(edit_voice_directive), NULL);
+    //gtk_widget_show(item);
+}
 
 /**
  * Create and insert a new staff into the score
@@ -222,24 +238,16 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
   g_assert (si != NULL);
   /* What gets added */
   gint ret = -1, err;
+  take_snapshot();
   DenemoStaff *thestaffstruct =
     (DenemoStaff *) g_malloc (sizeof (DenemoStaff));
 
-  //CREATE a GtkMenus to popup when clicking to left of the staff
-  {
-    //hmm, cannot populate it, why not ? FIXME 
-    GtkWidget *item;
-    thestaffstruct->staffmenu = (GtkMenu *)gtk_menu_new();
-    item = gtk_menu_item_new_with_label("Edit Attributes");
-    gtk_menu_shell_append(GTK_MENU_SHELL( thestaffstruct->staffmenu), item);
-    g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(edit_staff_directive), NULL);
-    gtk_widget_show(item);
-    thestaffstruct->voicemenu = (GtkMenu *)gtk_menu_new();
-    item = gtk_menu_item_new_with_label("Edit Attributes");
-    gtk_menu_shell_append(GTK_MENU_SHELL( thestaffstruct->voicemenu), item);
-    g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(edit_voice_directive), NULL);
-    gtk_widget_show(item);
-  }
+
+
+ 
+  thestaffstruct->staffmenu = create_menu(NULL);
+  thestaffstruct->voicemenu = create_menu(NULL);
+
 
   struct newstaffinfotopass itp;
   measurenode *themeasures = NULL;	/* Initial set of measures in staff */
@@ -333,10 +341,10 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action,
   thestaffstruct->denemo_name = g_string_new (NULL);
   thestaffstruct->lily_name = g_string_new (NULL);
 
-  thestaffstruct->staff_prolog = NULL;
-  thestaffstruct->lyrics_prolog = NULL;
-  thestaffstruct->figures_prolog = NULL;
-  thestaffstruct->fakechords_prolog = NULL;
+  //thestaffstruct->staff_prolog = NULL;
+  // thestaffstruct->lyrics_prolog = NULL;
+  //thestaffstruct->figures_prolog = NULL;
+  //thestaffstruct->fakechords_prolog = NULL;
   thestaffstruct->context = context;
   if (action == NEWVOICE)
     g_string_sprintf (thestaffstruct->denemo_name, _("poly voice %d"),
@@ -467,7 +475,7 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
     return;
   if(interactive &&  (curstaffstruct->context!=DENEMO_NONE))
     give_info = TRUE;
-    
+  take_snapshot();
   gboolean isprimary = ((int) curstaffstruct->voicenumber == 1);
   //FIXME free_staff()
 
