@@ -1,4 +1,4 @@
-/* utils.cpp
+/* utils.c
  * Functions useful across the different modules of
  * drawing and non-drawing code.
  *
@@ -25,22 +25,54 @@
 #endif
 #include "pitchentry.h"
 
-#ifdef __APPLE__
+#ifdef UNUSED__APPLE
 #include <mach-o/dyld.h>
 #endif
 
 void add_font_directory(gchar *fontpath) {
 #ifdef G_OS_WIN32
   AddFontResource(fontpath);
+  FcConfigAppFontAddDir(NULL, fontpath);
 #else
   FcConfigAppFontAddDir(NULL, fontpath);
 #endif
 }
+void add_font_file(gchar *fontname) {
+#ifdef G_OS_WIN32
+  AddFontResource(fontname);
+  FcConfigAppFontAddFile(NULL, fontname);
+
+#else
+  FcConfigAppFontAddFile(NULL, fontname);
+#endif
+}
 
 #ifdef G_OS_WIN32
 gboolean CoInitializeExCalled = FALSE;
 #endif
 
+// Create a unique temporary directory starting
+gchar *
+make_temp_dir(void) {
+  gchar *ret = NULL;
+#ifdef G_OS_WIN32
+  gchar buf[1024] = "C:\\TMP\\\0";
+  gint length = 1024;
+  (void) GetTempPath(length, buf);
+  gint integer = g_rand_int(g_rand_new());
+  ret = g_strdup_printf("%sDenemo%d", buf, integer);
+  
+  gint fail = g_mkdir_with_parents(ret, 0700);
+  if(fail)
+    g_print("Could not create temp dir %s\n", ret);
+  else
+    g_print("Created temp dir %s\n", ret);
+#else
+  ret = g_strdup("/tmp/DenemoXXXXXX");
+  mkdtemp((char *)ret);
+#endif
+return ret;
+}
 gboolean run_file_association(gchar *filename) {
 #ifdef G_OS_WIN32
   gint value = 0;
@@ -230,40 +262,30 @@ drawbitmapinverse_cr (cairo_t * cr, DenemoGraphic * mask, gint x,
 		   gint y)
 {
   cairo_save(cr);
-  if(mask->type==DENEMO_BITMAP) {
-  gdk_cairo_set_source_pixmap( cr, mask->graphic, x,y );//??? bitmap???? asks torbenh
-  cairo_rectangle( cr, x,y, mask->width, mask->height );
-  cairo_fill( cr );
-  
-  } else {
-    cairo_pattern_t *pattern = (cairo_pattern_t *)mask->graphic;
-    cairo_translate(cr, x, y);
-    // cairo_rectangle( cr, 0, 0,  mask->width, mask->height );
-    cairo_mask(cr, pattern);
+  switch (mask->type) {
+    case DENEMO_BITMAP: {
+      gdk_cairo_set_source_pixmap( cr, mask->graphic, x,y );//??? bitmap???? asks torbenh
+      cairo_rectangle( cr, x,y, mask->width, mask->height );
+      cairo_fill( cr );
+      break;
+    }
+    case DENEMO_PATTERN: {
+      cairo_pattern_t *pattern = (cairo_pattern_t *)mask->graphic;
+      cairo_translate(cr, x, y);
+      cairo_mask(cr, pattern);
+      break;
+    }
+    case DENEMO_FONT:{
+	DenemoGlyph *glyph = mask->graphic;
+	cairo_select_font_face( cr, glyph->fontname, glyph->slant, glyph->weight );
+	cairo_set_font_size( cr, glyph->size);
+	cairo_move_to( cr, x,y );
+	cairo_show_text( cr, glyph->utf);
+      break;	
+    }
   }
   cairo_restore( cr );
 }
-void
-drawfetachar (GdkPixmap * pixmap, GdkGC * gc, gunichar uc, gint x, gint y)
-{
-  int len;
-  char utf_string[8];
-  PangoContext *context =
-    gdk_pango_context_get_for_screen (gdk_drawable_get_screen (pixmap));
-  PangoLayout *layout = pango_layout_new (context);
-  PangoFontDescription *desc = pango_font_description_from_string ( "feta26 35px" );
-  pango_context_load_font( context, desc );
-
-  len = g_unichar_to_utf8( uc, utf_string );
-
-  pango_layout_set_font_description (layout, desc);
-  pango_layout_set_text (layout,
-			 utf_string,
-			 len);
-  PangoLayoutLine *line = pango_layout_get_line_readonly( layout, 0 );
-
-  gdk_draw_layout_line (pixmap, gc, x, y, line);
-}
 
 void
 drawfetachar_cr (cairo_t * cr, gunichar uc, double x, double y)
@@ -274,17 +296,15 @@ drawfetachar_cr (cairo_t * cr, gunichar uc, double x, double y)
   utf_string[len] = '\0';
   cairo_select_font_face( cr, "feta26", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL );
   cairo_set_font_size( cr, 35.0 );
-
-
   cairo_move_to( cr, x,y );
   cairo_show_text( cr, utf_string );
 }
 
 void drawtext_cr (cairo_t *cr, const char *text, double x, double y, double size)
 {
-  cairo_select_font_face( cr, "Sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD );
+  //use the FreeSerif font as it has music symbols - there is no font substitution done by cairo here
+  cairo_select_font_face( cr, "Denemo", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL );
   cairo_set_font_size( cr, size );
-
   cairo_move_to( cr, x,y );
   cairo_show_text( cr, text );
 
@@ -292,7 +312,6 @@ void drawtext_cr (cairo_t *cr, const char *text, double x, double y, double size
 void drawnormaltext_cr (cairo_t *cr, const char *text, double x, double y)
 {
   drawtext_cr(cr, text, x, y, 14.0);
-
 }
 void drawlargetext_cr (cairo_t *cr, const char *text, double x, double y)
 {
@@ -891,7 +910,7 @@ get_data_dir ()
     g_free (rootdir);
 #else /* not G_OS_WIN32 */
 
-#ifdef __APPLE__
+#ifdef UNUSED__APPLE
      
       {char path[1024];
        guint size = sizeof(path);
@@ -912,6 +931,41 @@ get_data_dir ()
   return datadir;
 }
 
+const gchar *
+get_bin_dir (void)
+{
+  static gchar *bindir = NULL;
+  if (bindir == NULL)
+  {
+#ifdef G_OS_WIN32
+    gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
+    bindir = g_build_filename (rootdir, "bin", NULL);
+    g_print ("rootdir=%s\n", rootdir);
+    g_print ("bindir=%s\n", bindir);
+    g_free (rootdir);
+#else /* not G_OS_WIN32 */
+
+#ifdef UNUSED__APPLE
+     
+      {char path[1024];
+       guint size = sizeof(path);
+       _NSGetExecutablePath(path, &size);
+       bindir = (gchar*)g_malloc(size);
+       if (_NSGetExecutablePath(bindir, &size) == 0)
+	 g_print("using bin path %s\n", bindir);
+       else
+	 g_critical("Cannot get bin dir\n");
+       
+       g_print("OSX set bin dir to %s\n", bindir);
+      }
+#else
+    bindir = gbr_find_bin_dir ("/usr/local/bin");
+#endif
+#endif /* not G_OS_WIN32 */
+  }
+  return bindir;
+}
+
 const gchar *
 get_conf_dir ()
 {
@@ -923,7 +977,7 @@ get_conf_dir ()
   confdir = g_build_filename (rootdir, "etc", "denemo", NULL);
   g_free (rootdir);
 #else /* not G_OS_WIN32 */
-#ifdef __APPLE__
+#ifdef UNUSED__APPLE
      
       {char path[1024];
        guint size = sizeof(path);
@@ -955,7 +1009,7 @@ get_locale_dir ()
     localedir = g_build_filename (rootdir, "share", "locale", NULL);
     g_free (rootdir);
 #else /* not G_OS_WIN32 */
-#ifdef __APPLE__
+#ifdef UNUSED__APPLE
      
       {char path[1024];
        guint size = sizeof(path);
@@ -999,11 +1053,152 @@ kill_process (GPid pid)
   g_spawn_close_pid (pid);
 }
 
+
+
+#define NOTE0 "<span font_desc=\"Denemo\">\xF0\x9D\x85\x9D</span>"
+#define NOTE1 "<span font_desc=\"Denemo\">\xF0\x9D\x85\x9E</span>"
+#define NOTE2 "<span font_desc=\"Denemo\">\xF0\x9D\x85\x9F</span>"
+#define NOTE3 "<span font_desc=\"Denemo\">\xF0\x9D\x85\xA0</span>"
+#define NOTE4 "<span font_desc=\"Denemo\">\xF0\x9D\x85\xA1</span>"
+#define NOTE5 "<span font_desc=\"Denemo\">\xF0\x9D\x85\xA2</span>"
+#define NOTE6 "<span font_desc=\"Denemo\">\xF0\x9D\x85\xA3</span>"
+#define NOTE7 "<span font_desc=\"Denemo\">\xF0\x9D\x85\xA4</span>"
+#define NOTE8 "<span font_desc=\"Denemo\">\xF0\x9D\x85\xA5</span>"
+
+#define REST0 "<span font_desc=\"Denemo\">\xF0\x9D\x84\xBB</span>"
+#define REST1 "<span font_desc=\"Denemo\">\xF0\x9D\x84\xBC</span>"
+#define REST2 "<span font_desc=\"Denemo\">\xF0\x9D\x84\xBD</span>"
+#define REST3 "<span font_desc=\"Denemo\">\xF0\x9D\x84\xBE</span>"
+#define REST4 "<span font_desc=\"Denemo\">\xF0\x9D\x84\xBF</span>"
+#define REST5 "<span font_desc=\"Denemo\">\xF0\x9D\x85\x80</span>"
+#define REST6 "<span font_desc=\"Denemo\">\xF0\x9D\x85\x81</span>"
+#define REST7 "<span font_desc=\"Denemo\">\xF0\x9D\x85\x82</span>"
+#define REST8 "<span font_desc=\"Denemo\">\xF0\x9D\x85\x83</span>"
+
+void
+init_denemo_notenames(void) {
+
+define_scheme_literal_variable("Denemo-Note0", NOTE0, NULL);
+define_scheme_literal_variable("Denemo-Rest0", REST0, NULL);
+define_scheme_literal_variable("Denemo-Note1", NOTE1, NULL);
+define_scheme_literal_variable("Denemo-Rest1", REST1, NULL);
+define_scheme_literal_variable("Denemo-Note2", NOTE2, NULL);
+define_scheme_literal_variable("Denemo-Rest2", REST2, NULL);
+define_scheme_literal_variable("Denemo-Note3", NOTE3, NULL);
+define_scheme_literal_variable("Denemo-Rest3", REST3, NULL);
+define_scheme_literal_variable("Denemo-Note4", NOTE4, NULL);
+define_scheme_literal_variable("Denemo-Rest4", REST4, NULL);
+define_scheme_literal_variable("Denemo-Note5", NOTE5, NULL);
+define_scheme_literal_variable("Denemo-Rest5", REST5, NULL);
+define_scheme_literal_variable("Denemo-Note6", NOTE6, NULL);
+define_scheme_literal_variable("Denemo-Rest6", REST6, NULL);
+define_scheme_literal_variable("Denemo-Note7", NOTE7, NULL);
+define_scheme_literal_variable("Denemo-Rest7", REST7, NULL);
+define_scheme_literal_variable("Denemo-Note8", NOTE8, NULL);
+define_scheme_literal_variable("Denemo-Rest8", REST8, NULL);
+
+}
 /* markup the passed string to be in the denemo music font
 * caller must free the returned string
 */
 gchar * music_font(gchar *str) {
-  return g_strdup_printf("<span font_desc=\"Denemo 12\">%s</span>", str);
+  GString *s = g_string_new("");
+  gint c = *str;
+  for(c = *str; c;c = *++str)
+    switch (c) {
+
+      case '0':  g_string_append(s, " "NOTE0" ");
+	break;
+      case HIGHLIGHT_OFFSET+'0': g_string_append(s, "<span background=\"blue\"> "NOTE0" </span>");
+	break;
+
+      case '1':  g_string_append(s, " "NOTE1" ");
+	break;
+      case HIGHLIGHT_OFFSET+'1': g_string_append(s, "<span background=\"blue\"> "NOTE1" </span>");
+	break;
+      case '2':  g_string_append(s, " "NOTE2" ");
+	break;
+      case HIGHLIGHT_OFFSET+'2': g_string_append(s, "<span background=\"blue\"> "NOTE2" </span>");
+	break;
+      case '3':  g_string_append(s, " "NOTE3" ");
+	break;
+      case HIGHLIGHT_OFFSET+'3': g_string_append(s, "<span background=\"blue\"> "NOTE3" </span>");
+	break;
+      case '4':  g_string_append(s, " "NOTE4" ");
+	break;
+      case HIGHLIGHT_OFFSET+'4': g_string_append(s, "<span background=\"blue\"> "NOTE4" </span>");
+	break;
+      case '5':  g_string_append(s, " "NOTE5" ");
+	break;
+      case HIGHLIGHT_OFFSET+'5': g_string_append(s, "<span background=\"blue\"> "NOTE5" </span>");
+	break;
+      case '6':  g_string_append(s, " "NOTE6" ");
+	break;
+      case HIGHLIGHT_OFFSET+'6': g_string_append(s, "<span background=\"blue\"> "NOTE6" </span>");
+	break;
+      case '7':  g_string_append(s, " "NOTE7" ");
+	break;
+      case HIGHLIGHT_OFFSET+'7': g_string_append(s, "<span background=\"blue\"> "NOTE7" </span>");
+	break;
+      case '8':  g_string_append(s, " "NOTE8" ");
+	break;
+      case HIGHLIGHT_OFFSET+'8': g_string_append(s, "<span background=\"blue\"> "NOTE8" </span>");
+	break;
+
+
+     case 'r':  g_string_append(s, " "REST0" ");
+	break;
+     case HIGHLIGHT_OFFSET+'r': g_string_append(s, "<span background=\"blue\"> "REST0" </span>");
+	break;
+
+     case 's':  g_string_append(s, " "REST1" ");
+	break;
+     case HIGHLIGHT_OFFSET+'s': g_string_append(s, "<span background=\"blue\"> "REST1" </span>");
+	break;
+     case 't':  g_string_append(s, " "REST2" ");
+	break;
+     case HIGHLIGHT_OFFSET+'t': g_string_append(s, "<span background=\"blue\"> "REST2" </span>");
+	break;
+     case 'u':  g_string_append(s, " "REST3" ");
+	break;
+     case HIGHLIGHT_OFFSET+'u': g_string_append(s, "<span background=\"blue\"> "REST3" </span>");
+	break;
+     case 'v':  g_string_append(s, " "REST4" ");
+	break;
+     case HIGHLIGHT_OFFSET+'v': g_string_append(s, "<span background=\"blue\"> "REST4" </span>");
+	break;
+     case 'w':  g_string_append(s, " "REST5" ");
+	break;
+     case HIGHLIGHT_OFFSET+'w': g_string_append(s, "<span background=\"blue\"> "REST5" </span>");
+	break;
+     case 'x':  g_string_append(s, " "REST6" ");
+	break;
+     case HIGHLIGHT_OFFSET+'x': g_string_append(s, "<span background=\"blue\"> "REST6" </span>");
+	break;
+     case 'y':  g_string_append(s, " "REST7" ");
+	break;
+     case HIGHLIGHT_OFFSET+'y': g_string_append(s, "<span background=\"blue\"> "REST7" </span>");
+	break;
+     case 'z':  g_string_append(s, " "REST8" ");
+	break;
+     case HIGHLIGHT_OFFSET+'z': g_string_append(s, "<span background=\"blue\"> "REST8" </span>");
+	break;
+
+
+
+
+
+
+
+
+
+
+
+	
+      default: g_string_append_c(s, c);
+      }
+  return g_string_free(s, FALSE);
+
 }
 
 void  set_title_bar(DenemoGUI *gui) {
@@ -1025,7 +1220,16 @@ void  set_title_bar(DenemoGUI *gui) {
   g_free(title);
   g_free(base);
 }
-
+static const gchar* enshift_string(gint enshift) {
+switch(enshift) {
+    case -2: return "bb";
+    case -1: return "b";
+    case 0: return " ";
+    case 1: return "#";
+    case 2: return "##";
+    default: return "Error";
+}
+}
 /* set the status of the current musical score - its change count and
    title bar and status bars.
    DenemoGUI *gui the musical score.
@@ -1174,7 +1378,7 @@ void write_status(DenemoGUI *gui) {
   GString  *status = g_string_new(_("Movement"));
 
   gint index = g_list_index(gui->movements, gui->si);
-  g_string_printf(status, " %d: %s: ", index+1, selection);
+  g_string_printf(status, "%s %d: %s: ", enshift_string(gui->si->pending_enshift), index+1, selection);
   if(gui->si->smf && (gui->si->smfsync == gui->si->changecount) && Denemo.prefs.playback_controls)
     g_string_append_printf(status, "%d min %.2f sec %.2f %.2f", minutes, seconds, early, late);
   else
@@ -1286,7 +1490,7 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
       	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
         gtk_widget_grab_focus (entry);
   	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_keep_above(GTK_WINDOW (dialog), TRUE);
         gtk_widget_show_all (dialog);
 
@@ -1304,9 +1508,10 @@ string_dialog_entry_with_widget (DenemoGUI *gui, gchar *wlabel, gchar *direction
 }
 
 static gboolean
-option_choice(GtkWidget *widget, DenemoDirective **response) {
+option_choice(GtkWidget *widget, gchar **response) {
   if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
     *response = g_object_get_data(G_OBJECT(widget), "choice");
+  //do not respond to the toggling off of other radio buttons
   return TRUE;
 }
 
@@ -1330,7 +1535,7 @@ gchar * get_option(gchar *str, gint length) {
   for(opt = str;(opt-str)<length;opt += strlen(opt)+1) {
     if(opt==str) {
       widget = widget1 = gtk_radio_button_new_with_label(NULL, opt);
-      response = opt;
+      response = str;//this is the first radio button, we set response to be the input string ie first option, in case the user makes no choice, in which case the callback option_choice is not called.
     } else {
       widget = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON (widget1), opt);
     }	
@@ -1343,6 +1548,7 @@ gchar * get_option(gchar *str, gint length) {
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_REJECT){ 
     response = NULL;
   }
+  g_debug("Returning contents of response is %s\n", response);
   gtk_widget_destroy(dialog);
   return response;
 }
