@@ -11,7 +11,7 @@
 #define UTILS_H
 
 #include <denemo/denemo.h>
-
+#define HIGHLIGHT_OFFSET (20) /* Fairly arbitrary value to transform codes '0', '1' ... to a new range with the meaning highlight the whole-note, half-note, ..., glyph */ 
 #define MAXEXTRASPACE (150) /* maximum space for ledger lines, for sanity */
 
 #define LINE_SPACE 10
@@ -135,11 +135,11 @@ headerfields(GtkWidget *dialog, GtkListStore *list_store,
 /* default isdialog shall be TRUE */
 
 
-void initdir ();
-const gchar *get_data_dir ();
-const gchar *get_conf_dir ();
-const gchar *get_locale_dir ();
-
+void initdir (void);
+const gchar *get_data_dir (void);
+const gchar *get_conf_dir (void);
+const gchar *get_locale_dir (void);
+const gchar *get_bin_dir (void);
 void kill_process (GPid pid);
 
 gchar * music_font(gchar *str);
@@ -276,9 +276,11 @@ void console_output(gchar *text);
 gint get_override(GList *g);
 
 void add_font_directory(gchar *fontpath);
+void add_font_file(gchar *fontpath);
 
 gboolean run_file_association(gchar *filenam);
-
+gchar *make_temp_dir(void);
 gchar *remove_extension(gchar *name);
 gchar *substitute_extension(gchar *name, gchar *extension);
+void init_denemo_notenames(void);
 #endif /* UTILS_H */
